"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _focus = require("@react-aria/focus");

var _button = require("@react-aria/button");

var _interactions = require("@react-aria/interactions");

var _utils = require("@react-aria/utils");

var _useWarning = _interopRequireDefault(require("../use-warning"));

var _drip = _interopRequireDefault(require("../utils/drip"));

var _utils2 = require("./utils");

var _buttonGroupContext = require("./button-group-context");

var _buttonIcon = _interopRequireDefault(require("./button-icon"));

var _clsx = _interopRequireDefault(require("../utils/clsx"));

var _useDrip = _interopRequireDefault(require("../use-drip"));

var _button2 = _interopRequireDefault(require("./button.styles"));

var _withDefaults = _interopRequireDefault(require("../utils/with-defaults"));

var _dom = require("../utils/dom");

var _assertion = require("../utils/assertion");

var _jsxRuntime = require("react/jsx-runtime");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultProps = {
  ghost: false,
  bordered: false,
  ripple: true,
  animated: true,
  disabled: false,
  autoFocus: false,
  auto: false,
  className: '',
  type: 'button'
};

const Button = /*#__PURE__*/_react.default.forwardRef(({
  onClick,
  onPress,
  as,
  css,
  ...btnProps
}, ref) => {
  const groupConfig = (0, _buttonGroupContext.useButtonGroupContext)();
  const filteredProps = (0, _utils2.filterPropsWithGroup)(btnProps, groupConfig);
  const cssColors = (0, _utils2.getCssColors)(filteredProps);
  /* eslint-disable @typescript-eslint/no-unused-vars */

  const {
    flat,
    children,
    disabled,
    animated,
    light,
    ripple,
    bordered,
    auto,
    borderWeight,
    icon,
    iconRight,
    ghost,
    autoFocus,
    className,
    ...props
  } = filteredProps;

  const handleDrip = e => {
    if (animated && ripple && buttonRef.current) {
      onDripClickHandler(e);
    }
  };

  const handleClick = e => {
    handleDrip(e);
    onClick == null ? void 0 : onClick(e);
  };

  const handlePress = e => {
    if (e.pointerType === 'keyboard' || e.pointerType === 'virtual') {
      handleDrip(e); // TODO: take this out and deprecate onClick function for next release (only use the @react-aria/button impl)

      onClick == null ? void 0 : onClick(e);
    }

    onPress == null ? void 0 : onPress(e);
  };

  const buttonRef = (0, _dom.useDOMRef)(ref);
  const {
    buttonProps,
    isPressed
  } = (0, _button.useButton)({ ...btnProps,
    onClick: handleClick,
    isDisabled: disabled,
    elementType: as,
    onPress: handlePress
  }, buttonRef);
  const {
    hoverProps,
    isHovered
  } = (0, _interactions.useHover)({
    isDisabled: disabled
  });
  const {
    isFocused,
    isFocusVisible,
    focusProps
  } = (0, _focus.useFocusRing)({
    autoFocus
  });
  const {
    onClick: onDripClickHandler,
    ...dripBindings
  } = (0, _useDrip.default)(false, buttonRef);
  /* eslint-enable @typescript-eslint/no-unused-vars */

  if (_assertion.__DEV__ && filteredProps.color === 'gradient' && (flat || light)) {
    (0, _useWarning.default)('Using the gradient color on flat and light buttons will have no effect.');
  }

  const hasIcon = icon || iconRight;
  const isRight = Boolean(iconRight);
  const getState = (0, _react.useMemo)(() => {
    if (isPressed) return 'pressed';
    if (isHovered) return 'hovered';
    return disabled ? 'disabled' : 'ready';
  }, [disabled, isHovered, isPressed]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_button2.default, {
    as: as,
    ref: buttonRef,
    borderWeight: borderWeight,
    auto: auto,
    flat: flat,
    light: light,
    ghost: ghost,
    bordered: bordered || ghost,
    "data-state": getState,
    animated: animated,
    isPressed: isPressed,
    isHovered: isHovered || ghost && isFocused,
    isFocusVisible: isFocusVisible && !disabled,
    className: (0, _clsx.default)('nextui-button', `nextui-button--${getState}`, className),
    css: { ...css,
      ...cssColors
    },
    ...(0, _utils.mergeProps)(buttonProps, focusProps, hoverProps, props),
    children: [_react.default.Children.count(children) === 0 ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_buttonIcon.default, {
      isSingle: true,
      isAuto: auto,
      isRight: isRight,
      isGradientButtonBorder: props.color === 'gradient' && (bordered || ghost),
      children: hasIcon
    }) : hasIcon ? /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_buttonIcon.default, {
        isSingle: false,
        isAuto: auto,
        isRight: isRight,
        isGradientButtonBorder: props.color === 'gradient' && (bordered || ghost),
        children: hasIcon
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
        className: (0, _clsx.default)('nextui-button-text', {
          'nextui-button-text-right': isRight,
          'nextui-button-text-left': !isRight
        }),
        children: children
      })]
    }) : /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
      className: "nextui-button-text",
      children: children
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_drip.default, {
      color: "white",
      ...dripBindings
    })]
  });
});

if (_assertion.__DEV__) {
  Button.displayName = 'NextUI.Button';
}

Button.toString = () => '.nextui-button';

var _default = (0, _withDefaults.default)(Button, defaultProps);

exports.default = _default;
module.exports = exports.default;