"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _utils = require("@react-aria/utils");

var _focus = require("@react-aria/focus");

var _interactions = require("@react-aria/interactions");

var _visuallyHidden = require("@react-aria/visually-hidden");

var _clsx = _interopRequireDefault(require("../utils/clsx"));

var _assertion = require("../utils/assertion");

var _dom = require("../utils/dom");

var _useCheckbox = require("./use-checkbox");

var _checkbox = require("./checkbox.styles");

var _jsxRuntime = require("react/jsx-runtime");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Checkbox = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    className,
    as,
    css,
    children,
    label,
    ...otherProps
  } = props;
  const {
    size,
    color,
    labelColor,
    isRounded,
    lineThrough,
    disableAnimation,
    isIndeterminate,
    inputRef,
    inputProps
  } = (0, _useCheckbox.useCheckbox)({ ...otherProps,
    children: children != null ? children : label
  });
  const domRef = (0, _dom.useFocusableRef)(ref, inputRef);
  const {
    hoverProps,
    isHovered
  } = (0, _interactions.useHover)({
    isDisabled: inputProps.disabled
  }); // TODO: Event's propagation wasn't stopped https://github.com/adobe/react-spectrum/issues/2383

  const {
    pressProps
  } = (0, _interactions.usePress)({
    isDisabled: inputProps.disabled
  });
  const {
    focusProps,
    isFocusVisible
  } = (0, _focus.useFocusRing)({
    autoFocus: inputProps.autoFocus
  });
  const checkboxState = (0, _react.useMemo)(() => {
    if (isHovered) return 'hovered';
    return isIndeterminate && inputProps.checked ? 'mixed' : inputProps.checked ? 'checked' : 'uncheked';
  }, [isHovered, isIndeterminate, inputProps.checked]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_checkbox.StyledCheckboxLabel, {
    ref: domRef,
    ...(0, _utils.mergeProps)(hoverProps, pressProps),
    className: (0, _clsx.default)('nextui-checkbox-label', `nextui-checkbox--${checkboxState}`, className),
    as: as,
    css: css,
    size: size,
    isDisabled: inputProps.disabled,
    disableAnimation: disableAnimation,
    children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_checkbox.StyledCheckboxContainer, {
      className: "nextui-checkbox-container",
      color: color,
      isRounded: isRounded,
      isHovered: isHovered,
      isDisabled: inputProps.disabled,
      isFocusVisible: isFocusVisible,
      disableAnimation: disableAnimation,
      ...focusProps,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_visuallyHidden.VisuallyHidden, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)("input", {
          ref: inputRef,
          className: "nextui-checkbox-input",
          ...(0, _utils.mergeProps)(inputProps, focusProps)
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_checkbox.StyledCheckboxMask, {
        className: "nextui-checkbox-mask",
        isChecked: inputProps.checked,
        isIndeterminate: isIndeterminate,
        disableAnimation: disableAnimation,
        children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_checkbox.StyledIconCheck, {
          className: "nextui-icon-check",
          size: size,
          isChecked: inputProps.checked,
          isIndeterminate: isIndeterminate,
          disableAnimation: disableAnimation,
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_checkbox.StyledIconCheckFirstLine, {
            className: "nextui-icon-check-line1",
            isChecked: inputProps.checked,
            isIndeterminate: isIndeterminate,
            disableAnimation: disableAnimation
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_checkbox.StyledIconCheckSecondLine, {
            className: "nextui-icon-check-line2",
            isChecked: inputProps.checked,
            isIndeterminate: isIndeterminate,
            disableAnimation: disableAnimation
          })]
        })
      })]
    }), (children || label) && /*#__PURE__*/(0, _jsxRuntime.jsx)(_checkbox.StyledCheckboxText, {
      className: "nextui-checkbox-text",
      color: labelColor,
      lineThrough: lineThrough,
      isChecked: inputProps.checked,
      isDisabled: inputProps.disabled,
      disableAnimation: disableAnimation,
      children: children || label
    })]
  });
});

if (_assertion.__DEV__) {
  Checkbox.displayName = 'NextUI.Checkbox';
}

Checkbox.toString = () => '.nextui-checkbox';

var _default = Checkbox;
exports.default = _default;
module.exports = exports.default;