"use strict";

exports.__esModule = true;
exports.useCheckbox = void 0;

var _react = require("react");

var _toggle = require("@react-stately/toggle");

var _checkbox = require("@react-aria/checkbox");

var _assertion = require("../utils/assertion");

var _checkboxContext = require("./checkbox-context");

/**
 * @internal
 */
const useCheckbox = props => {
  var _groupContext$size, _groupContext$color, _groupContext$labelCo;

  const groupContext = (0, _checkboxContext.useCheckboxGroupContext)();
  const {
    size = (_groupContext$size = groupContext == null ? void 0 : groupContext.size) != null ? _groupContext$size : 'md',
    color = (_groupContext$color = groupContext == null ? void 0 : groupContext.color) != null ? _groupContext$color : 'default',
    labelColor = (_groupContext$labelCo = groupContext == null ? void 0 : groupContext.labelColor) != null ? _groupContext$labelCo : 'default',
    lineThrough,
    isRounded = false,
    disableAnimation = false,
    isIndeterminate = false,
    ...otherProps
  } = props;

  if (groupContext && _assertion.__DEV__) {
    const warningMessage = 'The Checkbox.Group is being used, `%s` will be ignored. Use the `%s` of the Checkbox.Group instead.';

    if ('isSelected' in otherProps) {
      console.warn(warningMessage, 'isSelected', 'value');
    }

    if ('defaultSelected' in otherProps) {
      console.warn(warningMessage, 'defaultSelected', 'defaultValue');
    }
  }

  const inputRef = (0, _react.useRef)(null);
  const ariaCheckboxProps = (0, _react.useMemo)(() => {
    var _otherProps$value, _otherProps$isRequire;

    return { ...otherProps,
      isIndeterminate,
      value: (_otherProps$value = otherProps.value) != null ? _otherProps$value : '',
      isRequired: (_otherProps$isRequire = otherProps.isRequired) != null ? _otherProps$isRequire : false
    };
  }, [isIndeterminate, otherProps]);
  const {
    inputProps
  } = groupContext ? (0, _checkbox.useCheckboxGroupItem)({ ...ariaCheckboxProps,
    validationState: otherProps.validationState
  }, groupContext.groupState, inputRef) : (0, _checkbox.useCheckbox)(ariaCheckboxProps, (0, _toggle.useToggleState)(ariaCheckboxProps), inputRef);
  return {
    size,
    color,
    labelColor,
    isRounded,
    lineThrough,
    disableAnimation,
    isIndeterminate,
    inputRef,
    inputProps
  };
};

exports.useCheckbox = useCheckbox;