"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.PopoverContent = void 0;

var _react = _interopRequireDefault(require("react"));

var _overlays = require("@react-aria/overlays");

var _dialog = require("@react-aria/dialog");

var _focus = require("@react-aria/focus");

var _utils = require("@react-aria/utils");

var _cssTransition = _interopRequireDefault(require("../utils/css-transition"));

var _assertion = require("../utils/assertion");

var _refs = require("../utils/refs");

var _popover = require("./popover.styles");

var _popoverContext = require("./popover-context");

var _utils2 = require("./utils");

var _clsx = _interopRequireDefault(require("../utils/clsx"));

var _jsxRuntime = require("react/jsx-runtime");

const PopoverContent = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    as,
    css,
    className,
    ...otherProps
  } = props;
  const {
    state,
    placement,
    overlayRef,
    disableAnimation,
    shouldCloseOnBlur,
    isDismissable,
    isKeyboardDismissDisabled,
    shouldCloseOnInteractOutside,
    getPopoverProps,
    onClose,
    onEntered,
    onExited
  } = (0, _popoverContext.usePopoverContext)();
  const transformOrigin = (0, _utils2.getTransformOrigin)(placement); // Hide content outside the modal from screen readers.

  const {
    modalProps
  } = (0, _overlays.useModal)({
    isDisabled: true
  });
  const {
    dialogProps
  } = (0, _dialog.useDialog)({
    role: 'dialog'
  }, overlayRef);
  const {
    overlayProps
  } = (0, _overlays.useOverlay)({
    onClose,
    isOpen: state.isOpen,
    isDismissable: isDismissable && state.isOpen,
    shouldCloseOnBlur,
    isKeyboardDismissDisabled,
    shouldCloseOnInteractOutside
  }, overlayRef);
  const {
    isFocusVisible,
    focusProps
  } = (0, _focus.useFocusRing)();
  const contents = /*#__PURE__*/(0, _jsxRuntime.jsxs)(_popover.StyledPopoverContentContainer, {
    ref: (0, _refs.mergeRefs)(overlayRef, ref),
    ...getPopoverProps((0, _utils.mergeProps)(overlayProps, modalProps, dialogProps, focusProps, otherProps)),
    className: (0, _clsx.default)('nextui-popover-content-container', className),
    isFocusVisible: isFocusVisible,
    as: as,
    css: {
      transformOrigin,
      ...css
    },
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_overlays.DismissButton, {
      onDismiss: onClose
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_popover.StyledPopoverContent, {
      className: "nextui-popover-content",
      children: children
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_overlays.DismissButton, {
      onDismiss: onClose
    })]
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {
    children: !disableAnimation ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_focus.FocusScope, {
      restoreFocus: true,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_cssTransition.default, {
        visible: state.isOpen,
        name: "nextui-popover-content",
        enterTime: 20,
        leaveTime: 60,
        clearTime: 300,
        onExited: onExited,
        onEntered: onEntered,
        children: contents
      })
    }) : state.isOpen ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_focus.FocusScope, {
      restoreFocus: true,
      children: contents
    }) : null
  });
});

exports.PopoverContent = PopoverContent;

if (_assertion.__DEV__) {
  PopoverContent.displayName = 'NextUI.PopoverContent';
}

PopoverContent.toString = () => '.nextui-popover-content';