"use strict";

exports.__esModule = true;
exports.usePopover = usePopover;

var _react = require("react");

var _overlays = require("@react-aria/overlays");

var _overlays2 = require("@react-stately/overlays");

var _refs = require("../utils/refs");

var _utils = require("./utils");

/**
 * @internal
 */
function usePopover(props = {}) {
  const {
    isOpen,
    defaultOpen,
    onOpenChange,
    shouldFlip = true,
    offset = 12,
    placement = 'bottom',
    onClose,
    triggerType = 'dialog',
    isDismissable = true,
    shouldCloseOnBlur = false,
    isKeyboardDismissDisabled = false,
    disableAnimation = false,
    shouldCloseOnInteractOutside
  } = props;
  const triggerRef = (0, _react.useRef)(null);
  const overlayRef = (0, _react.useRef)(null);
  const state = (0, _overlays2.useOverlayTriggerState)({
    isOpen,
    defaultOpen,
    onOpenChange
  });
  const [exited, setExited] = (0, _react.useState)(!state.isOpen);
  const getState = (0, _react.useMemo)(() => {
    if (state.isOpen) return 'open';
    return 'closed';
  }, [state.isOpen]);
  const handleClose = (0, _react.useCallback)(() => {
    onClose == null ? void 0 : onClose();
    state.close();
  }, [state, onClose]);
  const onEntered = (0, _react.useCallback)(() => {
    setExited(false);
  }, []);
  const onExited = (0, _react.useCallback)(() => {
    setExited(true);
  }, []);
  const {
    triggerProps,
    overlayProps
  } = (0, _overlays.useOverlayTrigger)({
    type: triggerType
  }, state, triggerRef);
  const overlayPlacement = (0, _react.useMemo)(() => (0, _utils.getAriaPlacement)(placement), [placement]);
  const {
    overlayProps: positionProps
  } = (0, _overlays.useOverlayPosition)({
    isOpen: state.isOpen,
    targetRef: triggerRef,
    placement: overlayPlacement,
    overlayRef,
    shouldFlip,
    offset
  });
  const getTriggerProps = (0, _react.useCallback)((props = {}, _ref = null) => {
    return { ...props,
      ...triggerProps,
      ref: (0, _refs.mergeRefs)(triggerRef, _ref)
    };
  }, [triggerRef, triggerProps]);
  const getPopoverProps = (0, _react.useCallback)((props = {}) => {
    return { ...props,
      ...overlayProps,
      ...positionProps,
      'data-state': getState,
      'data-placement': placement
    };
  }, [getState, positionProps, overlayProps, placement]);
  return {
    state,
    exited,
    overlayRef,
    triggerRef,
    placement,
    disableAnimation,
    shouldCloseOnBlur,
    isDismissable,
    isKeyboardDismissDisabled,
    shouldCloseOnInteractOutside,
    isOpen: state.isOpen,
    onClose: handleClose,
    onExited,
    onEntered,
    triggerProps,
    overlayProps,
    positionProps,
    getTriggerProps,
    getPopoverProps
  };
}