"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _table = require("./table.styles");

var _utils = require("@react-aria/utils");

var _tableRowGroup = _interopRequireDefault(require("./table-row-group"));

var _tableRow = _interopRequireDefault(require("./table-row"));

var _tableCell = _interopRequireDefault(require("./table-cell"));

var _tableCheckboxCell = _interopRequireDefault(require("./table-checkbox-cell"));

var _tableContext = require("./table-context");

var _utils2 = require("./utils");

var _index = require("../index");

var _clsx = _interopRequireDefault(require("../utils/clsx"));

var _jsxRuntime = require("react/jsx-runtime");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// TODO: Remove this once we have a better way to pass it from the parent
const SCROLL_OFFSET = 40;

const TableBody = ({
  children,
  collection,
  state,
  animated,
  color,
  hasPagination,
  hideLoading,
  ...props
}) => {
  var _collection$body, _collection$body$prop, _collection$body2, _collection$body2$pro, _collection$body4, _collection$body4$pro;

  const {
    currentPage,
    rowsPerPage
  } = (0, _tableContext.useTableContext)();
  const infinityScroll = (0, _react.useMemo)(() => (0, _utils2.isInfinityScroll)(collection), [collection.body.props]);
  const isLoading = ((_collection$body = collection.body) == null ? void 0 : (_collection$body$prop = _collection$body.props) == null ? void 0 : _collection$body$prop.loadingState) === 'loading' || ((_collection$body2 = collection.body) == null ? void 0 : (_collection$body2$pro = _collection$body2.props) == null ? void 0 : _collection$body2$pro.loadingState) === 'loadingMore';
  const rows = (0, _react.useMemo)(() => {
    const data = [...collection.body.childNodes];

    if (!hasPagination) {
      return data;
    }

    return data == null ? void 0 : data.slice((currentPage - 1) * rowsPerPage, currentPage * rowsPerPage);
  }, [hasPagination, collection, currentPage, rowsPerPage]);
  const completeSpaces = (0, _react.useMemo)(() => {
    const rowsCount = rows.length;

    if (rowsCount >= rowsPerPage && !infinityScroll) {
      return null;
    }

    return /*#__PURE__*/(0, _jsxRuntime.jsx)("tr", {
      role: "row",
      className: "nextui-table-hidden-row",
      "aria-hidden": "true",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_table.StyledBaseTableCell, {
        "aria-hidden": "true",
        colSpan: collection.columnCount,
        style: (0, _utils.mergeProps)({
          '--nextui--tableBodyEmptySpaceHeight': infinityScroll ? 'var(--nextui-space-10)' : `calc(${rowsPerPage - rowsCount} * var(--nextui-space-14))`
        }, (props == null ? void 0 : props.style) || {}),
        css: {
          height: 'var(--nextui--tableBodyEmptySpaceHeight)'
        }
      })
    });
  }, [collection.columnCount, rows, rowsPerPage, infinityScroll]); // handle scroll and call next page on infinity scroll

  const handleScroll = e => {
    if (!infinityScroll) {
      return;
    }

    const element = e.target;
    const isAtBottom = element.scrollHeight - (element.scrollTop + SCROLL_OFFSET) <= element.clientHeight;

    if (isAtBottom && !isLoading) {
      var _collection$body3, _collection$body3$pro;

      (_collection$body3 = collection.body) == null ? void 0 : (_collection$body3$pro = _collection$body3.props) == null ? void 0 : _collection$body3$pro.onLoadMore == null ? void 0 : _collection$body3$pro.onLoadMore();
    }
  };

  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_tableRowGroup.default, {
    as: "tbody",
    className: (0, _clsx.default)('nextui-table-body', props.className),
    isInfinityScroll: infinityScroll,
    onScroll: handleScroll,
    css: {
      pb: '$10',
      position: 'relative',
      ...props.css,
      ...((_collection$body4 = collection.body) == null ? void 0 : (_collection$body4$pro = _collection$body4.props) == null ? void 0 : _collection$body4$pro.css)
    },
    ...props,
    children: [children, rows == null ? void 0 : rows.map(row => {
      if (!row.hasChildNodes) {
        return null;
      }

      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableRow.default, {
        "aria-hidden": "false",
        item: row,
        state: state,
        children: [...row.childNodes].map(cell => {
          var _cell$props;

          return cell != null && (_cell$props = cell.props) != null && _cell$props.isSelectionCell ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableCheckboxCell.default, {
            cell: cell,
            state: state,
            color: color,
            animated: animated
          }, cell == null ? void 0 : cell.key) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableCell.default, {
            cell: cell,
            state: state
          }, cell == null ? void 0 : cell.key);
        })
      }, row == null ? void 0 : row.key);
    }), !hideLoading && isLoading && /*#__PURE__*/(0, _jsxRuntime.jsx)(_table.StyledTableLoadingRow, {
      role: "row",
      className: "nextui-table-hidden-row",
      "aria-hidden": "true",
      isAtEnd: rows.length > 0,
      isAbsolute: !infinityScroll,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_table.StyledBaseTableCell, {
        "aria-hidden": "true",
        colSpan: collection.columnCount,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Loading, {
          color: color
        })
      })
    }), completeSpaces]
  });
};

TableBody.displayName = 'NextUI.TableBody';

TableBody.toString = () => '.nextui-table-body';

var _default = TableBody;
exports.default = _default;
module.exports = exports.default;