"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _table = require("@react-aria/table");

var _table2 = require("@react-stately/table");

var _index = require("../index");

var _tableRowGroup = _interopRequireDefault(require("./table-row-group"));

var _tableColumnHeader = _interopRequireDefault(require("./table-column-header"));

var _tableHeaderRow = _interopRequireDefault(require("./table-header-row"));

var _tableSelectAllCheckbox = _interopRequireDefault(require("./table-select-all-checkbox"));

var _tablePagination = _interopRequireDefault(require("./table-pagination"));

var _tableFooter = _interopRequireDefault(require("./table-footer"));

var _tableBody = _interopRequireDefault(require("./table-body"));

var _collections = require("../utils/collections");

var _table3 = require("./table.styles");

var _tableContext = _interopRequireDefault(require("./table-context"));

var _propTypes = require("../utils/prop-types");

var _utils = require("./utils");

var _withDefaults = _interopRequireDefault(require("../utils/with-defaults"));

var _clsx = _interopRequireDefault(require("../utils/clsx"));

var _jsxRuntime = require("react/jsx-runtime");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultProps = {
  animated: true,
  hideLoading: false,
  selectionMode: 'none',
  selectionBehavior: 'toggle'
};

const Table = /*#__PURE__*/_react.default.forwardRef((tableProps, ref) => {
  const {
    selectionMode,
    selectionBehavior,
    hideLoading,
    children,
    shadow,
    color,
    animated,
    borderWeight,
    bordered,
    containerCss,
    ...props
  } = tableProps;
  const [withoutPaginationChildren, paginationChildren] = (0, _collections.pickSingleChild)(children, _tablePagination.default);
  const {
    hasPagination,
    rowsPerPage
  } = (0, _utils.hasPaginationChild)(children, _tablePagination.default);
  const state = (0, _table2.useTableState)({ ...tableProps,
    children: withoutPaginationChildren,
    showSelectionCheckboxes: tableProps.showSelectionCheckboxes !== undefined ? tableProps.showSelectionCheckboxes : selectionMode === 'multiple' && selectionBehavior !== 'replace'
  }); // clean table props

  Object.keys(props).forEach(propNameKey => {
    if (_propTypes.excludedTableProps.indexOf(propNameKey) > -1) {
      // @ts-ignored
      delete props[propNameKey];
    }
  });
  const tableRef = (0, _react.useRef)(null);
  (0, _react.useImperativeHandle)(ref, () => tableRef == null ? void 0 : tableRef.current);
  const {
    collection
  } = state;
  const {
    gridProps
  } = (0, _table.useTable)(tableProps, state, tableRef);

  const initialValues = _react.default.useMemo(() => {
    return {
      collection,
      color,
      animated,
      rowsPerPage
    };
  }, [collection, animated, color, rowsPerPage]);

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableContext.default.Provider, {
    defaultValues: initialValues,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_table3.StyledTableContainer, {
      shadow: shadow,
      borderWeight: borderWeight,
      bordered: bordered,
      className: "nextui-table-container",
      css: { ...containerCss
      },
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_table3.StyledTable, {
        ref: tableRef,
        color: color,
        shadow: shadow,
        animated: animated,
        hoverable: selectionMode !== 'none' || props.hoverable,
        isMultiple: selectionMode === 'multiple',
        hasPagination: hasPagination,
        className: (0, _clsx.default)('nextui-table', props.className),
        ...gridProps,
        ...props,
        children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_tableRowGroup.default, {
          as: "thead",
          isFixed: (0, _utils.isInfinityScroll)(collection),
          children: [collection.headerRows.map(headerRow => /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableHeaderRow.default, {
            item: headerRow,
            state: state,
            children: [...headerRow.childNodes].map(column => {
              var _column$props;

              return column != null && (_column$props = column.props) != null && _column$props.isSelectionCell ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableSelectAllCheckbox.default, {
                column: column,
                state: state,
                color: color,
                animated: animated
              }, column == null ? void 0 : column.key) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableColumnHeader.default, {
                column: column,
                state: state,
                animated: animated
              }, column == null ? void 0 : column.key);
            })
          }, headerRow == null ? void 0 : headerRow.key)), !props.sticked && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Spacer, {
            as: "tr",
            className: "nextui-table-hidden-row",
            y: 0.4
          })]
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_tableBody.default, {
          state: state,
          color: color,
          collection: collection,
          animated: animated,
          hasPagination: hasPagination,
          hideLoading: hideLoading
        }), hasPagination && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_tableFooter.default, {
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Spacer, {
            as: "tr",
            className: "nextui-table-hidden-row",
            y: 0.6
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)("tr", {
            role: "row",
            children: /*#__PURE__*/(0, _jsxRuntime.jsx)("th", {
              tabIndex: -1,
              role: "columnheader",
              colSpan: collection.columnCount,
              children: paginationChildren
            })
          })]
        })]
      })
    })
  });
});

Table.displayName = 'NextUI.Table';

Table.toString = () => '.nextui-table';

var _default = (0, _withDefaults.default)(Table, defaultProps);

exports.default = _default;
module.exports = exports.default;