"use strict";

exports.__esModule = true;
exports.renameProp = exports.omitObject = exports.isObject = exports.getKeyValue = exports.copyObject = exports.cleanObjectKeys = exports.cleanObject = void 0;

const isObject = target => target && typeof target === 'object';

exports.isObject = isObject;

const renameProp = (oldProp, newProp, {
  [oldProp]: old,
  ...others
}) => ({
  [newProp]: old,
  ...others
}); // copy an object without reference


exports.renameProp = renameProp;

const copyObject = obj => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  return { ...obj
  };
}; // copy an object omit some keys


exports.copyObject = copyObject;

const omitObject = (obj, omitKeys) => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  const newObj = { ...obj
  };
  omitKeys.forEach(key => newObj[key] && delete newObj[key]);
  return newObj;
}; // clean undefined and null values


exports.omitObject = omitObject;

const cleanObject = obj => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  const newObj = { ...obj
  };
  Object.keys(newObj).forEach(key => {
    if (newObj[key] === undefined || newObj[key] === null) {
      delete newObj[key];
    }
  });
  return newObj;
};

exports.cleanObject = cleanObject;

const cleanObjectKeys = (obj, keys = []) => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  const newObj = { ...obj
  };
  keys.forEach(key => {
    if (newObj[key]) {
      delete newObj[key];
    }
  });
  return newObj;
};

exports.cleanObjectKeys = cleanObjectKeys;

const getKeyValue = (obj, key) => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  return obj[key];
};

exports.getKeyValue = getKeyValue;