import React, { useMemo, useState, useRef, useEffect } from 'react';
import { useDOMRef } from '../utils/dom';
import { __DEV__ } from '../utils/assertion';
import StyledAvatar from './avatar.styles';
import clsx from '../utils/clsx';
import useForkRef from '../use-fork-ref';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

const safeText = text => {
  if ((text == null ? void 0 : text.length) <= 4) return text;
  return text == null ? void 0 : text.slice(0, 3);
};

export const Avatar = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    src,
    text,
    icon,
    alt,
    className,
    imgRef: imgRefProp,
    ...otherProps
  } = props;
  const domRef = useDOMRef(ref);
  const showText = !src;
  const [ready, setReady] = useState(false);
  const imgRef = useRef(null);
  const handleImgRef = useForkRef(imgRefProp, imgRef);
  useEffect(() => {
    var _imgRef$current;

    (imgRef == null ? void 0 : (_imgRef$current = imgRef.current) == null ? void 0 : _imgRef$current.complete) && setReady(true);
  }, []);
  const getState = useMemo(() => {
    return !ready && src ? 'loading' : 'ready';
  }, [src, ready]);
  return /*#__PURE__*/_jsxs(StyledAvatar, {
    ref: domRef,
    className: clsx({
      'only-text-avatar': showText
    }, className),
    "data-state": getState,
    ...otherProps,
    children: [/*#__PURE__*/_jsx("span", {
      className: "nextui-avatar-bg"
    }), !showText && /*#__PURE__*/_jsx("img", {
      ref: handleImgRef,
      className: clsx('nextui-avatar-img', `nextui-avatar--${getState}`, {
        'nextui-avatar-ready': ready
      }),
      src: src,
      alt: alt,
      "data-state": getState,
      onLoad: () => setReady(true)
    }), showText && !icon && text && /*#__PURE__*/_jsx("span", {
      className: "nextui-avatar-text",
      children: safeText(text)
    }), icon && /*#__PURE__*/_jsx("span", {
      className: "nextui-avatar-icon",
      children: icon
    })]
  });
});

if (__DEV__) {
  Avatar.displayName = 'NextUI.Avatar';
}

Avatar.toString = () => '.nextui-avatar';

export default Avatar;