/* eslint-disable @typescript-eslint/no-explicit-any */
import React, { useCallback, useMemo } from 'react';
import withDefaults from '../utils/with-defaults';
import CSSTransition from '../utils/css-transition';
import useCurrentState from '../use-current-state';
import cslx from '../utils/clsx';
import useKeyboard, { KeyCode } from '../use-keyboard';
import { StyledBackdrop, StyledBackdropLayer, StyledBackdropContent } from './backdrop.styles';
import { __DEV__ } from '../utils/assertion';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
const defaultProps = {
  onClick: () => {},
  visible: false,
  blur: false,
  animated: true,
  preventDefault: true,
  opacity: 0.5,
  className: ''
};
const preClass = 'nextui-backdrop';
const Backdrop = /*#__PURE__*/React.memo(({
  children,
  onClick,
  onKeyPress,
  visible,
  maxWidth,
  blur,
  animated,
  opacity,
  preventDefault,
  className,
  css,
  ...props
}) => {
  const [, setIsContentMouseDown, IsContentMouseDownRef] = useCurrentState(false);

  const clickHandler = event => {
    if (IsContentMouseDownRef.current) return;
    onClick && onClick(event);
  };

  const childrenClickHandler = useCallback(event => {
    event.stopPropagation();
  }, []);

  const mouseUpHandler = () => {
    if (!IsContentMouseDownRef.current) return;
    const timer = setTimeout(() => {
      setIsContentMouseDown(false);
      clearTimeout(timer);
    }, 0);
  };

  const {
    bindings
  } = useKeyboard(ev => {
    onKeyPress && onKeyPress(ev);
  }, [KeyCode.Escape, KeyCode.Space], {
    disableGlobalEvent: true,
    preventDefault
  });
  const getState = useMemo(() => {
    return visible ? 'open' : 'closed';
  }, [visible]);
  const renderChildren = useMemo(() => {
    return /*#__PURE__*/_jsxs(StyledBackdrop, {
      tabIndex: -1,
      role: "button",
      "aria-hidden": true,
      "data-state": getState,
      onClick: clickHandler,
      onMouseUp: mouseUpHandler,
      css: {
        $$backdropOpacity: opacity,
        ...css
      },
      className: cslx(preClass, `${preClass}--${getState}`, className),
      ...bindings,
      ...props,
      children: [/*#__PURE__*/_jsx(StyledBackdropLayer, {
        className: cslx(`${preClass}-layer`, blur ? `${preClass}-layer-blur` : `${preClass}-layer-default`),
        animated: animated,
        blur: blur
      }), /*#__PURE__*/_jsx(StyledBackdropContent, {
        animated: animated,
        className: `${preClass}-content`,
        onClick: childrenClickHandler,
        css: {
          maxWidth
        },
        onMouseDown: () => setIsContentMouseDown(true),
        children: children
      })]
    });
  }, [children]);
  return /*#__PURE__*/_jsx(_Fragment, {
    children: animated ? /*#__PURE__*/_jsx(CSSTransition, {
      name: `${preClass}-wrapper`,
      visible: visible,
      enterTime: 20,
      leaveTime: 20,
      clearTime: 150,
      children: renderChildren
    }) : visible ? renderChildren : null
  });
});

if (__DEV__) {
  Backdrop.displayName = 'NextUI.Backdrop';
}

Backdrop.toString = () => '.nextui-backdrop';

export default withDefaults(Backdrop, defaultProps);