import React, { useMemo } from 'react';
import withDefaults from '../utils/with-defaults';
import { ButtonGroupContext } from './button-group-context';
import StyledButtonGroup from './button-group.styles';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  borderWeight: 'normal',
  size: 'md',
  color: 'default'
};

const ButtonGroup = groupProps => {
  const {
    disabled,
    size,
    color,
    bordered,
    ghost,
    light,
    flat,
    shadow,
    auto,
    animated,
    rounded,
    ripple,
    borderWeight,
    children,
    ...props
  } = groupProps;
  const initialValue = useMemo(() => ({
    disabled,
    size,
    color,
    bordered,
    light,
    ghost,
    flat,
    shadow,
    auto,
    borderWeight,
    animated,
    rounded,
    ripple,
    isButtonGroup: true
  }), [disabled, animated, size, ripple, color, bordered, light, ghost, flat, borderWeight]);
  return /*#__PURE__*/_jsx(ButtonGroupContext.Provider, {
    value: initialValue,
    children: /*#__PURE__*/_jsx(StyledButtonGroup, {
      size: size,
      bordered: bordered || ghost,
      gradient: groupProps.color === 'gradient',
      ...props,
      children: children
    })
  });
};

ButtonGroup.toString = () => '.nextui-button-group';

const MemoButtonGroup = /*#__PURE__*/React.memo(ButtonGroup);
export default withDefaults(MemoButtonGroup, defaultProps);