import React, { useMemo } from 'react';
import { useFocusRing } from '@react-aria/focus';
import { useButton } from '@react-aria/button';
import { useHover } from '@react-aria/interactions';
import { mergeProps } from '@react-aria/utils';
import useWarning from '../use-warning';
import ButtonDrip from '../utils/drip';
import { filterPropsWithGroup, getCssColors } from './utils';
import { useButtonGroupContext } from './button-group-context';
import ButtonIcon from './button-icon';
import clsx from '../utils/clsx';
import useDrip from '../use-drip';
import StyledButton from './button.styles';
import withDefaults from '../utils/with-defaults';
import { useDOMRef } from '../utils/dom';
import { __DEV__ } from '../utils/assertion';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const defaultProps = {
  ghost: false,
  bordered: false,
  ripple: true,
  animated: true,
  disabled: false,
  autoFocus: false,
  auto: false,
  className: '',
  type: 'button'
};
const Button = /*#__PURE__*/React.forwardRef(({
  onClick,
  onPress,
  as,
  css,
  ...btnProps
}, ref) => {
  const groupConfig = useButtonGroupContext();
  const filteredProps = filterPropsWithGroup(btnProps, groupConfig);
  const cssColors = getCssColors(filteredProps);
  /* eslint-disable @typescript-eslint/no-unused-vars */

  const {
    flat,
    children,
    disabled,
    animated,
    light,
    ripple,
    bordered,
    auto,
    borderWeight,
    icon,
    iconRight,
    ghost,
    autoFocus,
    className,
    ...props
  } = filteredProps;

  const handleDrip = e => {
    if (animated && ripple && buttonRef.current) {
      onDripClickHandler(e);
    }
  };

  const handleClick = e => {
    handleDrip(e);
    onClick == null ? void 0 : onClick(e);
  };

  const handlePress = e => {
    if (e.pointerType === 'keyboard' || e.pointerType === 'virtual') {
      handleDrip(e); // TODO: take this out and deprecate onClick function for next release (only use the @react-aria/button impl)

      onClick == null ? void 0 : onClick(e);
    }

    onPress == null ? void 0 : onPress(e);
  };

  const buttonRef = useDOMRef(ref);
  const {
    buttonProps,
    isPressed
  } = useButton({ ...btnProps,
    onClick: handleClick,
    isDisabled: disabled,
    elementType: as,
    onPress: handlePress
  }, buttonRef);
  const {
    hoverProps,
    isHovered
  } = useHover({
    isDisabled: disabled
  });
  const {
    isFocused,
    isFocusVisible,
    focusProps
  } = useFocusRing({
    autoFocus
  });
  const {
    onClick: onDripClickHandler,
    ...dripBindings
  } = useDrip(false, buttonRef);
  /* eslint-enable @typescript-eslint/no-unused-vars */

  if (__DEV__ && filteredProps.color === 'gradient' && (flat || light)) {
    useWarning('Using the gradient color on flat and light buttons will have no effect.');
  }

  const hasIcon = icon || iconRight;
  const isRight = Boolean(iconRight);
  const getState = useMemo(() => {
    if (isPressed) return 'pressed';
    if (isHovered) return 'hovered';
    return disabled ? 'disabled' : 'ready';
  }, [disabled, isHovered, isPressed]);
  return /*#__PURE__*/_jsxs(StyledButton, {
    as: as,
    ref: buttonRef,
    borderWeight: borderWeight,
    auto: auto,
    flat: flat,
    light: light,
    ghost: ghost,
    bordered: bordered || ghost,
    "data-state": getState,
    animated: animated,
    isPressed: isPressed,
    isHovered: isHovered || ghost && isFocused,
    isFocusVisible: isFocusVisible && !disabled,
    className: clsx('nextui-button', `nextui-button--${getState}`, className),
    css: { ...css,
      ...cssColors
    },
    ...mergeProps(buttonProps, focusProps, hoverProps, props),
    children: [React.Children.count(children) === 0 ? /*#__PURE__*/_jsx(ButtonIcon, {
      isSingle: true,
      isAuto: auto,
      isRight: isRight,
      isGradientButtonBorder: props.color === 'gradient' && (bordered || ghost),
      children: hasIcon
    }) : hasIcon ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(ButtonIcon, {
        isSingle: false,
        isAuto: auto,
        isRight: isRight,
        isGradientButtonBorder: props.color === 'gradient' && (bordered || ghost),
        children: hasIcon
      }), /*#__PURE__*/_jsx("div", {
        className: clsx('nextui-button-text', {
          'nextui-button-text-right': isRight,
          'nextui-button-text-left': !isRight
        }),
        children: children
      })]
    }) : /*#__PURE__*/_jsx("span", {
      className: "nextui-button-text",
      children: children
    }), /*#__PURE__*/_jsx(ButtonDrip, {
      color: "white",
      ...dripBindings
    })]
  });
});

if (__DEV__) {
  Button.displayName = 'NextUI.Button';
}

Button.toString = () => '.nextui-button';

export default withDefaults(Button, defaultProps);