import React, { useImperativeHandle, useRef } from 'react';
import Image from '../image';
import Drip from '../utils/drip';
import useDrip from '../use-drip';
import { hasChild, pickChild } from '../utils/collections';
import useKeyboard, { KeyCode } from '../use-keyboard';
import { StyledCard, StyledCardHeader as CardHeader, StyledCardFooter as CardFooter, StyledCardBody as CardBody } from './card.styles';
import withDefaults from '../utils/with-defaults';
import { __DEV__ } from '../utils/assertion';
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  animated: true,
  ripple: true,
  cover: false,
  preventDefault: false
};
const Card = /*#__PURE__*/React.forwardRef(({ ...cardProps
}, ref) => {
  const {
    children,
    cover,
    animated,
    ripple,
    clickable,
    onClick,
    preventDefault,
    ...props
  } = cardProps;
  const cardRef = useRef(null);
  useImperativeHandle(ref, () => cardRef.current);
  const {
    onClick: onDripClickHandler,
    ...dripBindings
  } = useDrip(false, cardRef);
  const [withoutHeaderChildren, headerChildren] = pickChild(children, CardHeader);
  const [withoutFooterChildren, footerChildren] = pickChild(withoutHeaderChildren, CardFooter);
  const [withoutImageChildren, imageChildren] = pickChild(withoutFooterChildren, Image);
  const hasContent = hasChild(withoutImageChildren, CardBody);
  const hasHeader = hasChild(children, CardHeader);

  const clickHandler = event => {
    if (animated && cardRef.current) {
      onDripClickHandler(event);
    }

    onClick && onClick(event);
  };

  const {
    bindings
  } = useKeyboard(event => {
    if (!clickable) {
      return;
    }

    clickHandler(event);
  }, [KeyCode.Enter, KeyCode.Space], {
    disableGlobalEvent: true,
    preventDefault
  });
  return /*#__PURE__*/_jsxs(StyledCard, {
    ref: cardRef,
    role: clickable ? 'button' : 'section',
    cover: cover,
    animated: animated,
    clickable: clickable,
    tabIndex: clickable ? 0 : -1,
    onClick: clickHandler,
    ...props,
    ...bindings,
    children: [hasHeader ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [headerChildren, imageChildren]
    }) : imageChildren, hasContent ? withoutImageChildren : !cover ? /*#__PURE__*/_jsx(CardBody, {
      children: withoutImageChildren
    }) : null, clickable && animated && ripple && /*#__PURE__*/_jsx(Drip, { ...dripBindings
    }), footerChildren]
  });
});

if (__DEV__) {
  Card.displayName = 'NextUI.Card';
}

Card.toString = () => '.nextui-card';

export default withDefaults(Card, defaultProps);