import React from 'react';
import clsx from '../utils/clsx';
import { useDOMRef } from '../utils/dom';
import { __DEV__ } from '../utils/assertion';
import { CheckboxGroupProvider } from './checkbox-context';
import { useCheckboxGroup } from './use-checkbox-group';
import { StyledCheckboxGroup, StyledCheckboxGroupContainer } from './checkbox.styles';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const CheckboxGroup = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    children,
    className,
    as,
    label,
    ...otherProps
  } = props;
  const {
    css,
    ...context
  } = useCheckboxGroup({ ...otherProps,
    label
  });
  const domRef = useDOMRef(ref);
  return /*#__PURE__*/_jsxs(StyledCheckboxGroup, {
    ref: domRef,
    ...context.groupProps,
    className: clsx('nextui-checkbox-group', className),
    size: context.size,
    isDisabled: context.groupState.isDisabled,
    as: as,
    css: css,
    children: [label && /*#__PURE__*/_jsx("label", {
      className: "nextui-checkbox-group-label",
      ...context.labelProps,
      children: label
    }), /*#__PURE__*/_jsx(StyledCheckboxGroupContainer, {
      className: "nextui-checkbox-group-items",
      role: "presentation",
      isRow: context.isRow,
      children: /*#__PURE__*/_jsx(CheckboxGroupProvider, {
        value: context,
        children: children
      })
    })]
  });
});

if (__DEV__) {
  CheckboxGroup.displayName = 'NextUI.CheckboxGroup';
}

CheckboxGroup.toString = () => '.nextui-checkbox-group';

export default CheckboxGroup;