import React, { useMemo } from 'react';
import { mergeProps } from '@react-aria/utils';
import { useFocusRing } from '@react-aria/focus';
import { useHover } from '@react-aria/interactions';
import { usePress } from '@react-aria/interactions';
import { VisuallyHidden } from '@react-aria/visually-hidden';
import clsx from '../utils/clsx';
import { __DEV__ } from '../utils/assertion';
import { useFocusableRef } from '../utils/dom';
import { useCheckbox } from './use-checkbox';
import { StyledCheckboxLabel, StyledCheckboxContainer, StyledCheckboxMask, StyledIconCheck, StyledIconCheckFirstLine, StyledIconCheckSecondLine, StyledCheckboxText } from './checkbox.styles';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const Checkbox = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    className,
    as,
    css,
    children,
    label,
    ...otherProps
  } = props;
  const {
    size,
    color,
    labelColor,
    isRounded,
    lineThrough,
    disableAnimation,
    isIndeterminate,
    inputRef,
    inputProps
  } = useCheckbox({ ...otherProps,
    children: children != null ? children : label
  });
  const domRef = useFocusableRef(ref, inputRef);
  const {
    hoverProps,
    isHovered
  } = useHover({
    isDisabled: inputProps.disabled
  }); // TODO: Event's propagation wasn't stopped https://github.com/adobe/react-spectrum/issues/2383

  const {
    pressProps
  } = usePress({
    isDisabled: inputProps.disabled
  });
  const {
    focusProps,
    isFocusVisible
  } = useFocusRing({
    autoFocus: inputProps.autoFocus
  });
  const checkboxState = useMemo(() => {
    if (isHovered) return 'hovered';
    return isIndeterminate && inputProps.checked ? 'mixed' : inputProps.checked ? 'checked' : 'uncheked';
  }, [isHovered, isIndeterminate, inputProps.checked]);
  return /*#__PURE__*/_jsxs(StyledCheckboxLabel, {
    ref: domRef,
    ...mergeProps(hoverProps, pressProps),
    className: clsx('nextui-checkbox-label', `nextui-checkbox--${checkboxState}`, className),
    as: as,
    css: css,
    size: size,
    isDisabled: inputProps.disabled,
    disableAnimation: disableAnimation,
    children: [/*#__PURE__*/_jsxs(StyledCheckboxContainer, {
      className: "nextui-checkbox-container",
      color: color,
      isRounded: isRounded,
      isHovered: isHovered,
      isDisabled: inputProps.disabled,
      isFocusVisible: isFocusVisible,
      disableAnimation: disableAnimation,
      ...focusProps,
      children: [/*#__PURE__*/_jsx(VisuallyHidden, {
        children: /*#__PURE__*/_jsx("input", {
          ref: inputRef,
          className: "nextui-checkbox-input",
          ...mergeProps(inputProps, focusProps)
        })
      }), /*#__PURE__*/_jsx(StyledCheckboxMask, {
        className: "nextui-checkbox-mask",
        isChecked: inputProps.checked,
        isIndeterminate: isIndeterminate,
        disableAnimation: disableAnimation,
        children: /*#__PURE__*/_jsxs(StyledIconCheck, {
          className: "nextui-icon-check",
          size: size,
          isChecked: inputProps.checked,
          isIndeterminate: isIndeterminate,
          disableAnimation: disableAnimation,
          children: [/*#__PURE__*/_jsx(StyledIconCheckFirstLine, {
            className: "nextui-icon-check-line1",
            isChecked: inputProps.checked,
            isIndeterminate: isIndeterminate,
            disableAnimation: disableAnimation
          }), /*#__PURE__*/_jsx(StyledIconCheckSecondLine, {
            className: "nextui-icon-check-line2",
            isChecked: inputProps.checked,
            isIndeterminate: isIndeterminate,
            disableAnimation: disableAnimation
          })]
        })
      })]
    }), (children || label) && /*#__PURE__*/_jsx(StyledCheckboxText, {
      className: "nextui-checkbox-text",
      color: labelColor,
      lineThrough: lineThrough,
      isChecked: inputProps.checked,
      isDisabled: inputProps.disabled,
      disableAnimation: disableAnimation,
      children: children || label
    })]
  });
});

if (__DEV__) {
  Checkbox.displayName = 'NextUI.Checkbox';
}

Checkbox.toString = () => '.nextui-checkbox';

export default Checkbox;