import { useMemo, useRef } from 'react';
import { useToggleState } from '@react-stately/toggle';
import { useCheckbox as useReactAriaCheckbox, useCheckboxGroupItem as useReactAriaCheckboxGroupItem } from '@react-aria/checkbox';
import { __DEV__ } from '../utils/assertion';
import { useCheckboxGroupContext } from './checkbox-context';

/**
 * @internal
 */
export const useCheckbox = props => {
  var _groupContext$size, _groupContext$color, _groupContext$labelCo;

  const groupContext = useCheckboxGroupContext();
  const {
    size = (_groupContext$size = groupContext == null ? void 0 : groupContext.size) != null ? _groupContext$size : 'md',
    color = (_groupContext$color = groupContext == null ? void 0 : groupContext.color) != null ? _groupContext$color : 'default',
    labelColor = (_groupContext$labelCo = groupContext == null ? void 0 : groupContext.labelColor) != null ? _groupContext$labelCo : 'default',
    lineThrough,
    isRounded = false,
    disableAnimation = false,
    isIndeterminate = false,
    ...otherProps
  } = props;

  if (groupContext && __DEV__) {
    const warningMessage = 'The Checkbox.Group is being used, `%s` will be ignored. Use the `%s` of the Checkbox.Group instead.';

    if ('isSelected' in otherProps) {
      console.warn(warningMessage, 'isSelected', 'value');
    }

    if ('defaultSelected' in otherProps) {
      console.warn(warningMessage, 'defaultSelected', 'defaultValue');
    }
  }

  const inputRef = useRef(null);
  const ariaCheckboxProps = useMemo(() => {
    var _otherProps$value, _otherProps$isRequire;

    return { ...otherProps,
      isIndeterminate,
      value: (_otherProps$value = otherProps.value) != null ? _otherProps$value : '',
      isRequired: (_otherProps$isRequire = otherProps.isRequired) != null ? _otherProps$isRequire : false
    };
  }, [isIndeterminate, otherProps]);
  const {
    inputProps
  } = groupContext ? useReactAriaCheckboxGroupItem({ ...ariaCheckboxProps,
    validationState: otherProps.validationState
  }, groupContext.groupState, inputRef) : useReactAriaCheckbox(ariaCheckboxProps, useToggleState(ariaCheckboxProps), inputRef);
  return {
    size,
    color,
    labelColor,
    isRounded,
    lineThrough,
    disableAnimation,
    isIndeterminate,
    inputRef,
    inputProps
  };
};