import React, { useMemo } from 'react';
import withDefaults from '../utils/with-defaults';
import { CollapseContext } from './collapse-context';
import useCurrentState from '../use-current-state';
import { setChildrenIndex } from '../utils/collections';
import { StyledCollapseGroup } from './collapse.styles';
import Collapse from './collapse';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  accordion: true
};

const CollapseGroup = ({
  children,
  accordion,
  animated,
  divider,
  onChange,
  ...props
}) => {
  const [state, setState, stateRef] = useCurrentState([]);

  const updateValues = (currentIndex, nextState) => {
    const hasChild = stateRef.current.find(val => val === currentIndex);
    onChange && onChange(currentIndex, nextState);

    if (accordion) {
      if (nextState) return setState([currentIndex]);
      return setState([]);
    }

    if (nextState) {
      // In a few cases, the user will set Collapse Component state manually.
      // If the user incorrectly set the state, Group component should ignore it.

      /* istanbul ignore if */
      if (hasChild) return;
      return setState([...stateRef.current, currentIndex]);
    }

    setState(stateRef.current.filter(item => item !== currentIndex));
  };

  const initialValue = useMemo(() => ({
    values: state,
    updateValues,
    divider,
    animated
  }), [state.join(',')]);
  const hasIndexChildren = useMemo(() => setChildrenIndex(children, [Collapse]), [children]);
  return /*#__PURE__*/_jsx(CollapseContext.Provider, {
    value: initialValue,
    children: /*#__PURE__*/_jsx(StyledCollapseGroup, { ...props,
      children: hasIndexChildren
    })
  });
};

CollapseGroup.toString = () => '.nextui-collapse-group';

export default withDefaults(CollapseGroup, defaultProps);