import React, { useMemo } from 'react';
import StyledContainer from './container.styles';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  gap: 2,
  xs: false,
  sm: false,
  md: false,
  lg: false,
  xl: false,
  responsive: true,
  fluid: false,
  wrap: 'wrap',
  as: 'div',
  display: 'block'
};

const Container = ({
  xs,
  sm,
  md,
  lg,
  xl,
  wrap,
  gap,
  as,
  display,
  justify,
  direction,
  alignItems,
  alignContent,
  children,
  responsive,
  fluid,
  css,
  ...props
}) => {
  const gapUnit = useMemo(() => {
    return `calc(${gap} * $space$sm)`;
  }, [gap]);

  const getMaxWidth = () => {
    if (xs) return '$breakpoints$xs';
    if (sm) return '$breakpoints$sm';
    if (md) return '$breakpoints$md';
    if (lg) return '$breakpoints$lg';
    if (xl) return '$breakpoints$xl';
    return '';
  };

  return /*#__PURE__*/_jsx(StyledContainer, {
    css: {
      px: gapUnit,
      maxWidth: getMaxWidth(),
      alignItems,
      alignContent,
      flexWrap: wrap,
      display: display,
      justifyContent: justify,
      flexDirection: direction,
      ...css
    },
    responsive: responsive,
    fluid: fluid,
    as: as,
    ...props,
    children: children
  });
};

Container.toString = () => '.nextui-container';

Container.defaultProps = defaultProps;
export default /*#__PURE__*/React.memo(Container);