import React, { useMemo } from 'react';
import withDefaults from '../utils/with-defaults';
import { getMargin } from '../utils/dimensions';
import { StyledDivider, StyledDividerText } from './divider.styles';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  x: 0,
  y: 0,
  height: 1,
  align: 'center'
};

const Divider = ({
  height,
  x,
  y,
  align,
  children,
  textColor,
  css,
  ...props
}) => {
  const alignCss = useMemo(() => {
    if (!align || align === 'center') return '';

    if (align === 'left' || align === 'start') {
      return {
        transform: 'translateY(-50%)',
        left: '7%'
      };
    }

    return {
      transform: 'translateY(-50%)',
      left: 'auto',
      right: '7%'
    };
  }, [align]);
  const top = y ? getMargin(y / 2) : 0;
  const left = x ? getMargin(x / 2) : 0;
  return /*#__PURE__*/_jsx(StyledDivider, {
    role: "separator",
    css: {
      margin: `${top} ${left}`,
      height: `calc(${height} * 1px)`,
      ...css
    },
    ...props,
    children: children && /*#__PURE__*/_jsx(StyledDividerText, {
      css: { ...alignCss
      },
      color: textColor,
      className: "nextui-divider-text",
      children: children
    })
  });
};

Divider.toString = () => '.nextui-divider';

const MemoDivider = /*#__PURE__*/React.memo(Divider);
export default withDefaults(MemoDivider, defaultProps);