import React, { useMemo } from 'react';
import { StyledGridItem } from './grid.styles';
import clsx from '../utils/clsx';
import withDefaults from '../utils/with-defaults';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  xs: false,
  sm: false,
  md: false,
  lg: false,
  xl: false,
  className: ''
};

const getItemLayout = val => {
  const display = val === 0 ? 'none' : 'inherit';

  if (typeof val === 'number') {
    const width = 100 / 12 * val;
    const ratio = width > 100 ? '100%' : width < 0 ? '0' : `${width}%`;
    return {
      flexGrow: 0,
      display,
      maxWidth: ratio,
      flexBasis: ratio
    };
  }

  return {
    flexGrow: 1,
    display,
    maxWidth: '100%',
    flexBasis: '0'
  };
};

const GridItem = /*#__PURE__*/React.forwardRef(({
  xs,
  sm,
  md,
  lg,
  xl,
  css,
  justify,
  direction,
  alignItems,
  alignContent,
  children,
  className,
  ...props
}, ref) => {
  const classes = useMemo(() => {
    const breaks = {
      xs,
      sm,
      md,
      lg,
      xl
    };
    const classString = Object.keys(breaks).reduce((pre, name) => {
      if (breaks[name] !== undefined && breaks[name] !== false) return `${pre} ${name}`;
      return pre;
    }, '');
    return classString.trim();
  }, [xs, sm, md, lg, xl]);
  return /*#__PURE__*/_jsx(StyledGridItem, {
    ref: ref,
    className: clsx('nextui-grid-item', classes, className),
    css: {
      alignItems,
      alignContent,
      justifyContent: justify,
      flexDirection: direction,
      '&.xs': { ...getItemLayout(xs)
      },
      '@xsMax': {
        '&.xs': { ...getItemLayout(xs)
        }
      },
      '@sm': {
        '&.sm': { ...getItemLayout(sm)
        }
      },
      '@md': {
        '&.md': { ...getItemLayout(md)
        }
      },
      '@lg': {
        '&.lg': { ...getItemLayout(lg)
        }
      },
      '@xl': {
        '&.xl': { ...getItemLayout(xl)
        }
      },
      ...css
    },
    ...props,
    children: children
  });
});
GridItem.displayName = 'NextUI.GridItem';

GridItem.toString = () => '.nextui-grid-item';

export default withDefaults(GridItem, defaultProps);