import React, { useContext, useMemo } from 'react';
import withDefaults from '../utils/with-defaults';
import { ModalContext } from './modal-context';
import { StyledModalBody } from './modal.styles';
import cslx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  className: '',
  autoMargin: true
};
const preClass = 'nextui-modal-body';

const ModalBody = ({
  className,
  children,
  autoMargin: autoMarginProp,
  ...props
}) => {
  const {
    autoMargin: autoMarginContext,
    noPadding
  } = useContext(ModalContext);
  const autoMargin = useMemo(() => {
    return autoMarginContext !== undefined ? autoMarginContext : autoMarginProp;
  }, [autoMarginProp, autoMarginContext]);
  return /*#__PURE__*/_jsx(StyledModalBody, {
    className: cslx(preClass, {
      [`${preClass}-auto-margin`]: autoMargin,
      [`${preClass}-no-padding`]: noPadding
    }, className),
    autoMargin: autoMargin,
    noPadding: noPadding,
    ...props,
    children: children
  });
};

ModalBody.toString = () => '.nextui-modal-body';

const MemoModalBody = /*#__PURE__*/React.memo(ModalBody);
export default withDefaults(MemoModalBody, defaultProps);