import React, { useMemo, useContext } from 'react';
import withDefaults from '../utils/with-defaults';
import { ModalContext } from './modal-context';
import { StyledModalFooter } from './modal.styles';
import cslx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  className: '',
  justify: 'flex-end',
  autoMargin: true
};
const preClass = 'nextui-modal-footer';

const ModalFooter = ({
  children,
  className,
  justify,
  autoMargin: autoMarginProp,
  css,
  ...props
}) => {
  const {
    autoMargin: autoMarginContext,
    noPadding
  } = useContext(ModalContext);
  const autoMargin = useMemo(() => {
    return autoMarginContext !== undefined ? autoMarginContext : autoMarginProp;
  }, [autoMarginProp, autoMarginContext]);
  return /*#__PURE__*/_jsx(StyledModalFooter, {
    className: cslx(preClass, {
      [`${preClass}-auto-margin`]: autoMargin,
      [`${preClass}-no-padding`]: noPadding
    }, className),
    noPadding: noPadding,
    autoMargin: autoMargin,
    css: {
      justifyContent: justify,
      ...css
    },
    ...props,
    children: children
  });
};

ModalFooter.toString = () => '.nextui-modal-footer';

const MemoModalFooter = /*#__PURE__*/React.memo(ModalFooter);
export default withDefaults(MemoModalFooter, defaultProps);