import React, { useContext, useMemo } from 'react';
import withDefaults from '../utils/with-defaults';
import { ModalContext } from './modal-context';
import { StyledModalHeader } from './modal.styles';
import cslx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  className: '',
  justify: 'center',
  autoMargin: true
};
const preClass = 'nextui-modal-header';

const ModalHeader = ({
  children,
  className,
  justify,
  autoMargin: autoMarginProp,
  css,
  ...props
}) => {
  const {
    autoMargin: autoMarginContext,
    noPadding
  } = useContext(ModalContext);
  const autoMargin = useMemo(() => {
    return autoMarginContext !== undefined ? autoMarginContext : autoMarginProp;
  }, [autoMarginProp, autoMarginContext]);
  return /*#__PURE__*/_jsx(StyledModalHeader, {
    className: cslx(preClass, {
      [`${preClass}-auto-margin`]: autoMargin,
      [`${preClass}-no-padding`]: noPadding
    }, className),
    noPadding: noPadding,
    autoMargin: autoMargin,
    css: {
      justifyContent: justify,
      ...css
    },
    ...props,
    children: children
  });
};

ModalHeader.toString = () => '.nextui-modal-header';

const MemoModalHeader = /*#__PURE__*/React.memo(ModalHeader);
export default withDefaults(MemoModalHeader, defaultProps);