import React, { useEffect, useRef, useMemo, useState } from 'react';
import withDefaults from '../utils/with-defaults';
import CSSTransition from '../utils/css-transition';
import { isChildElement } from '../utils/collections';
import ModalCloseButton from './modal-close-button';
import { KeyCode } from '../use-keyboard';
import { StyledModal, StyledModalHideTab } from './modal.styles';
import cslx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
const defaultProps = {
  className: '',
  visible: false,
  rebound: false
};
const preClass = 'nextui-modal';

const ModalWrapper = ({
  className,
  children,
  visible,
  fullScreen,
  closeButton,
  rebound,
  animated,
  onCloseButtonClick,
  scroll,
  ...props
}) => {
  const modalContent = useRef(null);
  const tabStart = useRef(null);
  const tabEnd = useRef(null);
  const [rendered, setRendered] = useState(false);
  useEffect(() => {
    const timer = setTimeout(() => {
      setRendered(true);
      clearTimeout(timer);
    }, 300);
    return () => clearTimeout(timer);
  }, []);
  useEffect(() => {
    if (!visible) return;
    const activeElement = document.activeElement;
    const isChild = isChildElement(modalContent.current, activeElement);
    if (isChild) return;
    tabStart.current && tabStart.current.focus();
  }, [visible]);

  const onKeyDown = event => {
    const isTabDown = event.keyCode === KeyCode.Tab;
    if (!visible || !isTabDown) return;
    const activeElement = document.activeElement;

    if (event.shiftKey) {
      if (activeElement === tabStart.current) {
        tabEnd.current && tabEnd.current.focus();
      }
    } else {
      if (activeElement === tabEnd.current) {
        tabStart.current && tabStart.current.focus();
      }
    }
  };

  const handleClose = () => {
    onCloseButtonClick && onCloseButtonClick();
  };

  const getState = useMemo(() => {
    return visible ? 'open' : 'closed';
  }, [visible]);
  const renderChildren = useMemo(() => {
    return (
      /*#__PURE__*/
      // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions
      _jsxs(StyledModal, {
        role: "dialog",
        tabIndex: -1,
        "aria-modal": visible,
        ref: modalContent,
        "data-state": getState,
        fullScreen: fullScreen,
        scroll: scroll,
        closeButton: closeButton,
        className: cslx(preClass, `${preClass}--${getState}`, {
          [`${preClass}-fullscreen`]: fullScreen,
          [`${preClass}-with-close-button`]: closeButton,
          [`${preClass}-rebound`]: rebound,
          [`${preClass}-rendered`]: rendered
        }, className),
        ...props,
        onKeyDown: onKeyDown,
        children: [/*#__PURE__*/_jsx(StyledModalHideTab, {
          role: "button",
          tabIndex: 0,
          className: `${preClass}-hide-tab`,
          "aria-hidden": "true",
          ref: tabStart
        }), closeButton && /*#__PURE__*/_jsx(ModalCloseButton, {
          onClick: handleClose
        }), children, /*#__PURE__*/_jsx(StyledModalHideTab, {
          role: "button",
          tabIndex: 0,
          className: `${preClass}-hide-tab`,
          "aria-hidden": "true",
          ref: tabEnd
        })]
      })
    );
  }, [rebound, children]);
  return /*#__PURE__*/_jsx(_Fragment, {
    children: animated ? /*#__PURE__*/_jsx(CSSTransition, {
      name: `${preClass}-wrapper`,
      visible: visible,
      enterTime: 20,
      leaveTime: 20,
      clearTime: 300,
      children: renderChildren
    }) : visible ? renderChildren : null
  });
};

ModalWrapper.toString = () => '.nextui-modal-wrapper';

export default withDefaults(ModalWrapper, defaultProps);