import React, { useMemo, useEffect, useState } from 'react';
import clsx from '../utils/clsx';
import { StyledPaginationHighlight } from './pagination.styles';
import { mergeProps } from '@react-aria/utils';
import { jsx as _jsx } from "react/jsx-runtime";
const preClass = 'nextui-pagination-highlight';

const PaginationHighlight = ({
  active,
  shadow,
  noMargin,
  rounded,
  css,
  ...props
}) => {
  const [selfActive, setSelfActive] = useState(active);
  const [moveClassName, setMoveClassName] = useState('');
  useEffect(() => {
    if (active !== selfActive) {
      setSelfActive(active);
      setMoveClassName(`${preClass}--moving`);
      const timer = setTimeout(() => {
        setMoveClassName('');
        clearTimeout(timer);
      }, 350);
    }
  }, [active]);
  const leftValue = useMemo(() => noMargin ? `var(--nextui--paginationSize) * ${selfActive}` : `var(--nextui--paginationSize) * ${selfActive} + ${selfActive * 4 + 2}px`, [selfActive, noMargin]);
  return /*#__PURE__*/_jsx(StyledPaginationHighlight, {
    "aria-hidden": true,
    shadow: shadow,
    rounded: rounded,
    className: clsx(preClass, moveClassName, {
      [`${preClass}--rounded`]: rounded,
      [`${preClass}--active`]: active,
      [`${preClass}--no-margin`]: noMargin,
      [`${preClass}--shadow`]: shadow
    }, props.className),
    noMargin: noMargin,
    style: mergeProps({
      '--nextui--paginationLeft': `calc(${leftValue})`
    }, (props == null ? void 0 : props.style) || {}),
    css: {
      left: 'var(--nextui--paginationLeft)',
      ...css
    },
    ...props
  });
};

PaginationHighlight.toString = () => '.nextui-pagination-highlight';

export default PaginationHighlight;