import React, { useMemo } from 'react';
import { DOTS } from '../use-pagination';
import clsx from '../utils/clsx';
import withDefaults from '../utils/with-defaults';
import { StyledPaginationItem, StyledPaginationItemContent } from './pagination.styles';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  preserveContent: false
};

const getItemAriaLabel = page => {
  if (!page) return;

  switch (page) {
    case DOTS:
      return 'dots element';

    case '<':
      return 'previous page button';

    case '>':
      return 'next page button';

    case 'first':
      return 'first page button';

    case 'last':
      return 'last page button';

    default:
      return `${page} item`;
  }
};

const preClass = 'nextui-pagination-item';

const PaginationItem = ({
  active,
  value,
  children,
  disabled,
  animated,
  bordered,
  onClick,
  onlyDots,
  preserveContent,
  ...props
}) => {
  const ariaLabel = useMemo(() => active ? `${getItemAriaLabel(value)} active` : getItemAriaLabel(value), [value, active]);

  const clickHandler = event => {
    if (disabled) return;
    onClick && onClick(event);
  };

  return /*#__PURE__*/_jsx(StyledPaginationItem, {
    className: clsx(preClass, {
      [`${preClass}-active`]: active,
      [`${preClass}-animated`]: animated,
      [`${preClass}-disabled`]: disabled,
      [`${preClass}-bordered`]: bordered,
      [`${preClass}-only-dots`]: onlyDots,
      [`${preClass}-preserve-content`]: preserveContent
    }),
    animated: animated,
    active: active,
    disabled: disabled,
    bordered: bordered,
    onlyDots: onlyDots,
    preserveContent: preserveContent,
    onClick: clickHandler,
    "aria-label": ariaLabel,
    tabIndex: disabled ? -1 : 0,
    ...props,
    children: /*#__PURE__*/_jsx(StyledPaginationItemContent, {
      className: `${preClass}-content`,
      children: children
    })
  });
};

PaginationItem.toString = () => '.nextui-pagination-item';

export default withDefaults(PaginationItem, defaultProps);