import React from 'react';
import { useModal, useOverlay, DismissButton } from '@react-aria/overlays';
import { useDialog } from '@react-aria/dialog';
import { FocusScope, useFocusRing } from '@react-aria/focus';
import { mergeProps } from '@react-aria/utils';
import CSSTransition from '../utils/css-transition';
import { __DEV__ } from '../utils/assertion';
import { mergeRefs } from '../utils/refs';
import { StyledPopoverContentContainer, StyledPopoverContent } from './popover.styles';
import { usePopoverContext } from './popover-context';
import { getTransformOrigin } from './utils';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
export const PopoverContent = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    children,
    as,
    css,
    className,
    ...otherProps
  } = props;
  const {
    state,
    placement,
    overlayRef,
    disableAnimation,
    shouldCloseOnBlur,
    isDismissable,
    isKeyboardDismissDisabled,
    shouldCloseOnInteractOutside,
    getPopoverProps,
    onClose,
    onEntered,
    onExited
  } = usePopoverContext();
  const transformOrigin = getTransformOrigin(placement); // Hide content outside the modal from screen readers.

  const {
    modalProps
  } = useModal({
    isDisabled: true
  });
  const {
    dialogProps
  } = useDialog({
    role: 'dialog'
  }, overlayRef);
  const {
    overlayProps
  } = useOverlay({
    onClose,
    isOpen: state.isOpen,
    isDismissable: isDismissable && state.isOpen,
    shouldCloseOnBlur,
    isKeyboardDismissDisabled,
    shouldCloseOnInteractOutside
  }, overlayRef);
  const {
    isFocusVisible,
    focusProps
  } = useFocusRing();

  const contents = /*#__PURE__*/_jsxs(StyledPopoverContentContainer, {
    ref: mergeRefs(overlayRef, ref),
    ...getPopoverProps(mergeProps(overlayProps, modalProps, dialogProps, focusProps, otherProps)),
    className: clsx('nextui-popover-content-container', className),
    isFocusVisible: isFocusVisible,
    as: as,
    css: {
      transformOrigin,
      ...css
    },
    children: [/*#__PURE__*/_jsx(DismissButton, {
      onDismiss: onClose
    }), /*#__PURE__*/_jsx(StyledPopoverContent, {
      className: "nextui-popover-content",
      children: children
    }), /*#__PURE__*/_jsx(DismissButton, {
      onDismiss: onClose
    })]
  });

  return /*#__PURE__*/_jsx(_Fragment, {
    children: !disableAnimation ? /*#__PURE__*/_jsx(FocusScope, {
      restoreFocus: true,
      children: /*#__PURE__*/_jsx(CSSTransition, {
        visible: state.isOpen,
        name: "nextui-popover-content",
        enterTime: 20,
        leaveTime: 60,
        clearTime: 300,
        onExited: onExited,
        onEntered: onEntered,
        children: contents
      })
    }) : state.isOpen ? /*#__PURE__*/_jsx(FocusScope, {
      restoreFocus: true,
      children: contents
    }) : null
  });
});

if (__DEV__) {
  PopoverContent.displayName = 'NextUI.PopoverContent';
}

PopoverContent.toString = () => '.nextui-popover-content';