import * as React from 'react';
import { useButton } from '@react-aria/button';
import { mergeProps } from '@react-aria/utils';
import { usePopoverContext } from './popover-context';
import { pickChild } from '../utils/collections';
import { Button } from '../index';
import { __DEV__ } from '../utils/assertion';
/**
 * PopoverTrigger opens the popover's content. It must be an interactive element
 * such as `button` or `a`.
 */

export const PopoverTrigger = props => {
  const {
    state,
    triggerRef,
    getTriggerProps
  } = usePopoverContext();

  const onPress = () => state.open();

  const {
    buttonProps
  } = useButton({
    onPress
  }, triggerRef); // enforce a single child

  const child = React.Children.only(props.children); // validates if contains a NextUI Button as a child

  const [, triggerChildren] = pickChild(props.children, Button);
  const hasNextUIButton = (triggerChildren == null ? void 0 : triggerChildren[0]) !== undefined;
  return /*#__PURE__*/React.cloneElement(child, getTriggerProps(mergeProps(child.props, hasNextUIButton ? {
    onPress
  } : buttonProps), child.ref));
};

if (__DEV__) {
  PopoverTrigger.displayName = 'NextUI.PopoverTrigger';
}

PopoverTrigger.toString = () => '.nextui-popover-trigger';