import { useRef, useMemo, useState, useCallback } from 'react';
import { useOverlayPosition, useOverlayTrigger } from '@react-aria/overlays';
import { useOverlayTriggerState } from '@react-stately/overlays';
import { mergeRefs } from '../utils/refs';
import { getAriaPlacement } from './utils';

/**
 * @internal
 */
export function usePopover(props = {}) {
  const {
    isOpen,
    defaultOpen,
    onOpenChange,
    shouldFlip = true,
    offset = 12,
    placement = 'bottom',
    onClose,
    triggerType = 'dialog',
    isDismissable = true,
    shouldCloseOnBlur = false,
    isKeyboardDismissDisabled = false,
    disableAnimation = false,
    shouldCloseOnInteractOutside
  } = props;
  const triggerRef = useRef(null);
  const overlayRef = useRef(null);
  const state = useOverlayTriggerState({
    isOpen,
    defaultOpen,
    onOpenChange
  });
  const [exited, setExited] = useState(!state.isOpen);
  const getState = useMemo(() => {
    if (state.isOpen) return 'open';
    return 'closed';
  }, [state.isOpen]);
  const handleClose = useCallback(() => {
    onClose == null ? void 0 : onClose();
    state.close();
  }, [state, onClose]);
  const onEntered = useCallback(() => {
    setExited(false);
  }, []);
  const onExited = useCallback(() => {
    setExited(true);
  }, []);
  const {
    triggerProps,
    overlayProps
  } = useOverlayTrigger({
    type: triggerType
  }, state, triggerRef);
  const overlayPlacement = useMemo(() => getAriaPlacement(placement), [placement]);
  const {
    overlayProps: positionProps
  } = useOverlayPosition({
    isOpen: state.isOpen,
    targetRef: triggerRef,
    placement: overlayPlacement,
    overlayRef,
    shouldFlip,
    offset
  });
  const getTriggerProps = useCallback((props = {}, _ref = null) => {
    return { ...props,
      ...triggerProps,
      ref: mergeRefs(triggerRef, _ref)
    };
  }, [triggerRef, triggerProps]);
  const getPopoverProps = useCallback((props = {}) => {
    return { ...props,
      ...overlayProps,
      ...positionProps,
      'data-state': getState,
      'data-placement': placement
    };
  }, [getState, positionProps, overlayProps, placement]);
  return {
    state,
    exited,
    overlayRef,
    triggerRef,
    placement,
    disableAnimation,
    shouldCloseOnBlur,
    isDismissable,
    isKeyboardDismissDisabled,
    shouldCloseOnInteractOutside,
    isOpen: state.isOpen,
    onClose: handleClose,
    onExited,
    onEntered,
    triggerProps,
    overlayProps,
    positionProps,
    getTriggerProps,
    getPopoverProps
  };
}