import React, { useMemo } from 'react';
import CSSTransition from '../utils/css-transition';
import withDefaults from '../utils/with-defaults';
import { valueToPercent } from '../utils/numbers';
import { StyledProgress, StyledProgressBar } from './progress.styles';
import clsx from '../utils/clsx';
import { __DEV__ } from '../utils/assertion';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  striped: false,
  animated: true,
  shadow: false,
  indeterminated: false,
  value: 0,
  min: 0,
  max: 100
};
const preClass = 'nextui-progress';

const Progress = ({
  value: valueProp,
  max,
  min,
  striped,
  animated,
  shadow,
  indeterminated,
  css,
  ...props
}) => {
  const value = useMemo(() => valueProp > max ? max : valueProp < min ? min : valueProp, [valueProp, min, max]);
  const percent = useMemo(() => valueToPercent(value, min, max), [value, min, max]);
  return /*#__PURE__*/_jsx(StyledProgress, {
    role: "progressbar",
    indeterminated: indeterminated,
    css: {
      'nextui-progress-wrapper-enter': {
        opacity: 0
      },
      '.nextui-progress-wrapper-enter-active': {
        opacity: 1,
        width: `${percent}%`
      },
      ...css
    },
    ...props,
    children: /*#__PURE__*/_jsx(CSSTransition, {
      visible: true,
      name: `${preClass}-wrapper`,
      enterTime: 10,
      leaveTime: 20,
      clearTime: 300,
      children: /*#__PURE__*/_jsx(StyledProgressBar, {
        className: clsx(`${preClass}-bar`, {
          [`${preClass}-striped`]: striped,
          [`${preClass}-indeterminated`]: indeterminated
        }),
        "aria-valuenow": value,
        "aria-valuemin": min,
        "aria-valuemax": max,
        striped: striped,
        animated: animated,
        shadow: shadow,
        indeterminated: indeterminated,
        ...props
      })
    })
  });
};

if (__DEV__) {
  Progress.displayName = 'NextUI.Progress';
}

Progress.toString = () => '.nextui-progress';

const MemoProgress = /*#__PURE__*/React.memo(Progress);
export default withDefaults(MemoProgress, defaultProps);