import React, { useEffect, useMemo, useState } from 'react';
import withDefaults from '../utils/with-defaults';
import { RadioContext } from './radio-context';
import { useDOMRef } from '../utils/dom';
import { __DEV__ } from '../utils/assertion';
import { StyledRadioGroup } from './radio.styles';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  disabled: false,
  size: 'md',
  color: 'default',
  textColor: 'default'
};
export const RadioGroup = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    disabled,
    onChange,
    value,
    size,
    color,
    textColor,
    children,
    initialValue,
    ...otherProps
  } = props;
  const [selfVal, setSelfVal] = useState(initialValue);
  const domRef = useDOMRef(ref);

  const updateState = nextValue => {
    setSelfVal(nextValue);
    onChange && onChange(nextValue);
  };

  const providerValue = useMemo(() => {
    return {
      updateState,
      disabledAll: disabled,
      inGroup: true,
      size,
      color,
      textColor,
      value: selfVal
    };
  }, [disabled, selfVal]);
  useEffect(() => {
    if (value === undefined) return;
    setSelfVal(value);
  }, [value]);
  return /*#__PURE__*/_jsx(RadioContext.Provider, {
    value: providerValue,
    children: /*#__PURE__*/_jsx(StyledRadioGroup, {
      ref: domRef,
      role: "radiogroup",
      size: size,
      ...otherProps,
      children: children
    })
  });
});

if (__DEV__) {
  RadioGroup.displayName = 'NextUI.RadioGroup';
}

RadioGroup.toString = () => '.nextui-radio-group';

export default withDefaults(RadioGroup, defaultProps);