import React, { useMemo } from 'react';
import { StyledBaseTableCell, StyledTableLoadingRow } from './table.styles';
import { mergeProps } from '@react-aria/utils';
import TableRowGroup from './table-row-group';
import TableRow from './table-row';
import TableCell from './table-cell';
import TableCheckboxCell from './table-checkbox-cell';
import { useTableContext } from './table-context';
import { isInfinityScroll } from './utils';
import { Loading } from '../index';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
// TODO: Remove this once we have a better way to pass it from the parent
const SCROLL_OFFSET = 40;

const TableBody = ({
  children,
  collection,
  state,
  animated,
  color,
  hasPagination,
  hideLoading,
  ...props
}) => {
  var _collection$body, _collection$body$prop, _collection$body2, _collection$body2$pro, _collection$body4, _collection$body4$pro;

  const {
    currentPage,
    rowsPerPage
  } = useTableContext();
  const infinityScroll = useMemo(() => isInfinityScroll(collection), [collection.body.props]);
  const isLoading = ((_collection$body = collection.body) == null ? void 0 : (_collection$body$prop = _collection$body.props) == null ? void 0 : _collection$body$prop.loadingState) === 'loading' || ((_collection$body2 = collection.body) == null ? void 0 : (_collection$body2$pro = _collection$body2.props) == null ? void 0 : _collection$body2$pro.loadingState) === 'loadingMore';
  const rows = useMemo(() => {
    const data = [...collection.body.childNodes];

    if (!hasPagination) {
      return data;
    }

    return data == null ? void 0 : data.slice((currentPage - 1) * rowsPerPage, currentPage * rowsPerPage);
  }, [hasPagination, collection, currentPage, rowsPerPage]);
  const completeSpaces = useMemo(() => {
    const rowsCount = rows.length;

    if (rowsCount >= rowsPerPage && !infinityScroll) {
      return null;
    }

    return /*#__PURE__*/_jsx("tr", {
      role: "row",
      className: "nextui-table-hidden-row",
      "aria-hidden": "true",
      children: /*#__PURE__*/_jsx(StyledBaseTableCell, {
        "aria-hidden": "true",
        colSpan: collection.columnCount,
        style: mergeProps({
          '--nextui--tableBodyEmptySpaceHeight': infinityScroll ? 'var(--nextui-space-10)' : `calc(${rowsPerPage - rowsCount} * var(--nextui-space-14))`
        }, (props == null ? void 0 : props.style) || {}),
        css: {
          height: 'var(--nextui--tableBodyEmptySpaceHeight)'
        }
      })
    });
  }, [collection.columnCount, rows, rowsPerPage, infinityScroll]); // handle scroll and call next page on infinity scroll

  const handleScroll = e => {
    if (!infinityScroll) {
      return;
    }

    const element = e.target;
    const isAtBottom = element.scrollHeight - (element.scrollTop + SCROLL_OFFSET) <= element.clientHeight;

    if (isAtBottom && !isLoading) {
      var _collection$body3, _collection$body3$pro;

      (_collection$body3 = collection.body) == null ? void 0 : (_collection$body3$pro = _collection$body3.props) == null ? void 0 : _collection$body3$pro.onLoadMore == null ? void 0 : _collection$body3$pro.onLoadMore();
    }
  };

  return /*#__PURE__*/_jsxs(TableRowGroup, {
    as: "tbody",
    className: clsx('nextui-table-body', props.className),
    isInfinityScroll: infinityScroll,
    onScroll: handleScroll,
    css: {
      pb: '$10',
      position: 'relative',
      ...props.css,
      ...((_collection$body4 = collection.body) == null ? void 0 : (_collection$body4$pro = _collection$body4.props) == null ? void 0 : _collection$body4$pro.css)
    },
    ...props,
    children: [children, rows == null ? void 0 : rows.map(row => {
      if (!row.hasChildNodes) {
        return null;
      }

      return /*#__PURE__*/_jsx(TableRow, {
        "aria-hidden": "false",
        item: row,
        state: state,
        children: [...row.childNodes].map(cell => {
          var _cell$props;

          return cell != null && (_cell$props = cell.props) != null && _cell$props.isSelectionCell ? /*#__PURE__*/_jsx(TableCheckboxCell, {
            cell: cell,
            state: state,
            color: color,
            animated: animated
          }, cell == null ? void 0 : cell.key) : /*#__PURE__*/_jsx(TableCell, {
            cell: cell,
            state: state
          }, cell == null ? void 0 : cell.key);
        })
      }, row == null ? void 0 : row.key);
    }), !hideLoading && isLoading && /*#__PURE__*/_jsx(StyledTableLoadingRow, {
      role: "row",
      className: "nextui-table-hidden-row",
      "aria-hidden": "true",
      isAtEnd: rows.length > 0,
      isAbsolute: !infinityScroll,
      children: /*#__PURE__*/_jsx(StyledBaseTableCell, {
        "aria-hidden": "true",
        colSpan: collection.columnCount,
        children: /*#__PURE__*/_jsx(Loading, {
          color: color
        })
      })
    }), completeSpaces]
  });
};

TableBody.displayName = 'NextUI.TableBody';

TableBody.toString = () => '.nextui-table-body';

export default TableBody;