import React, { useRef, useImperativeHandle } from 'react';
import { useTableCell } from '@react-aria/table';
import { StyledTableCell } from './table.styles';
import { useFocusRing } from '@react-aria/focus';
import { mergeProps } from '@react-aria/utils';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const TableCell = /*#__PURE__*/React.forwardRef(({
  cell,
  state,
  ...props
}, ref) => {
  const tableCellRef = useRef(null);
  useImperativeHandle(ref, () => tableCellRef == null ? void 0 : tableCellRef.current);
  const {
    gridCellProps
  } = useTableCell({
    node: cell
  }, state, tableCellRef);
  const {
    isFocusVisible,
    focusProps
  } = useFocusRing();
  return /*#__PURE__*/_jsx(StyledTableCell, {
    ref: tableCellRef,
    isFocusVisible: isFocusVisible,
    className: clsx('nextui-table-cell', props.className),
    css: cell.props.css,
    ...mergeProps(gridCellProps, focusProps, props),
    children: cell.rendered
  });
});
TableCell.displayName = 'NextUI.TableCell';

TableCell.toString = () => '.nextui-table-cell';

export default TableCell;