import React, { useRef, useImperativeHandle } from 'react';
import { useTableCell, useTableSelectionCheckbox } from '@react-aria/table';
import { useFocusRing } from '@react-aria/focus';
import { mergeProps } from '@react-aria/utils';
import Checkbox from '../checkbox';
import { StyledTableCell } from './table.styles';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const TableCheckboxCell = /*#__PURE__*/React.forwardRef(({
  cell,
  state,
  color,
  animated,
  ...props
}, ref) => {
  const tableCellRef = useRef(null);
  useImperativeHandle(ref, () => tableCellRef == null ? void 0 : tableCellRef.current);
  const {
    gridCellProps
  } = useTableCell({
    node: cell
  }, state, tableCellRef);
  const {
    checkboxProps
  } = useTableSelectionCheckbox({
    key: (cell == null ? void 0 : cell.parentKey) || cell.key
  }, state);
  const {
    isFocusVisible,
    focusProps
  } = useFocusRing();
  return /*#__PURE__*/_jsx(StyledTableCell, {
    ref: tableCellRef,
    isFocusVisible: isFocusVisible,
    className: clsx('nextui-table-checkbox-cell', props.className),
    ...mergeProps(gridCellProps, focusProps, props),
    children: /*#__PURE__*/_jsx(Checkbox, { ...checkboxProps,
      color: color,
      disableAnimation: !animated,
      css: {
        display: 'inherit'
      }
    })
  });
});
TableCheckboxCell.displayName = 'NextUI.TableCheckboxCell';

TableCheckboxCell.toString = () => '.nextui-table-checkbox-cell';

export default TableCheckboxCell;