import React, { useRef, useImperativeHandle } from 'react';
import { useTableColumnHeader } from '@react-aria/table';
import { StyledTableColumnHeader } from './table.styles';
import { useFocusRing } from '@react-aria/focus';
import { mergeProps } from '@react-aria/utils';
import { VisuallyHidden } from '@react-aria/visually-hidden';
import TableSortIcon, { ICON_SIZE } from './table-sort-icon';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const TableColumnHeader = /*#__PURE__*/React.forwardRef(({
  column,
  state,
  ...props
}, ref) => {
  var _state$sortDescriptor, _state$sortDescriptor2;

  const tableColumnHeaderRef = useRef(null);
  useImperativeHandle(ref, () => tableColumnHeaderRef == null ? void 0 : tableColumnHeaderRef.current);
  const {
    columnHeaderProps
  } = useTableColumnHeader({
    node: column
  }, state, tableColumnHeaderRef);
  const {
    isFocusVisible,
    focusProps
  } = useFocusRing();
  const {
    hideHeader,
    ...columnProps
  } = column.props;
  return /*#__PURE__*/_jsxs(StyledTableColumnHeader, {
    ref: tableColumnHeaderRef,
    isFocusVisible: isFocusVisible,
    colSpan: column.colspan,
    className: clsx('nextui-table-column-header', props.className),
    ...mergeProps(props, columnHeaderProps, focusProps, columnProps),
    children: [hideHeader ? /*#__PURE__*/_jsx(VisuallyHidden, {
      children: column.rendered
    }) : column.rendered, columnProps.allowsSorting && /*#__PURE__*/_jsx(TableSortIcon, {
      visible: ((_state$sortDescriptor = state.sortDescriptor) == null ? void 0 : _state$sortDescriptor.column) === column.key,
      ascending: ((_state$sortDescriptor2 = state.sortDescriptor) == null ? void 0 : _state$sortDescriptor2.direction) === 'ascending',
      css: {
        position: 'absolute',
        m: '0 $2',
        bottom: `calc(50% - ${ICON_SIZE / 2}px)`
      }
    })]
  });
});
TableColumnHeader.displayName = 'NextUI.TableColumnHeader';

TableColumnHeader.toString = () => '.nextui-table-column-header';

export default TableColumnHeader;