import React, { useMemo } from 'react';
import { Pagination } from '../index';
import { useTableContext } from './table-context';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";

const TablePagination = ({
  align,
  rowsPerPage: rowsPerPageProp,
  onPageChange,
  ...props
}) => {
  const {
    color,
    animated,
    collection,
    footerAlign,
    rowsPerPage,
    setFooterAlign,
    setRowsPerPage,
    setCurrentPage
  } = useTableContext();
  React.useEffect(() => {
    if (align && align !== footerAlign) {
      setFooterAlign == null ? void 0 : setFooterAlign(align);
    }
  }, [align, footerAlign]);
  React.useEffect(() => {
    if (rowsPerPageProp && rowsPerPageProp !== rowsPerPage) {
      setRowsPerPage == null ? void 0 : setRowsPerPage(rowsPerPageProp);
    }
  }, [rowsPerPage, rowsPerPageProp]);

  const handlePageChanged = page => {
    setCurrentPage == null ? void 0 : setCurrentPage(page);
    onPageChange == null ? void 0 : onPageChange(page);
  };

  const totalPagination = useMemo(() => {
    var _collection$body;

    const rowsCount = collection != null && collection.body ? [...(collection == null ? void 0 : (_collection$body = collection.body) == null ? void 0 : _collection$body.childNodes)].length : 0;
    return rowsPerPage > 0 ? Math.ceil(rowsCount / rowsPerPage) : 1;
  }, [collection, rowsPerPage]);
  return /*#__PURE__*/_jsx(Pagination, {
    total: totalPagination,
    animated: animated,
    onChange: handlePageChanged,
    color: props.color || color,
    className: clsx('nextui-table-pagination', props.className),
    ...props
  });
};

TablePagination.displayName = 'NextUI.TablePagination';

TablePagination.toString = () => '.nextui-table-pagination';

export default TablePagination;