import React, { useRef, useImperativeHandle } from 'react';
import { useTableRow } from '@react-aria/table';
import { StyledTableRow } from './table.styles';
import { useFocusRing } from '@react-aria/focus';
import { mergeProps } from '@react-aria/utils';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const TableRow = /*#__PURE__*/React.forwardRef(({
  children,
  item,
  state,
  ...props
}, ref) => {
  const tableRowRef = useRef(null);
  useImperativeHandle(ref, () => tableRowRef == null ? void 0 : tableRowRef.current);
  const {
    rowProps
  } = useTableRow({
    node: item
  }, state, tableRowRef);
  const {
    isFocusVisible,
    focusProps
  } = useFocusRing();
  const isDisabled = state.disabledKeys.has(item.key);
  return /*#__PURE__*/_jsx(StyledTableRow, {
    ref: tableRowRef,
    isFocusVisible: isFocusVisible,
    isSelected: !!rowProps['aria-selected'],
    isDisabled: isDisabled,
    className: clsx('nextui-table-row', {
      'nextui-table-row--selected': rowProps['aria-selected'],
      'nextui-table-row--disabled': isDisabled
    }, props.className),
    css: item.props.css,
    ...mergeProps(rowProps, focusProps, props),
    children: children
  });
});
TableRow.displayName = 'NextUI.TableRow';

TableRow.toString = () => '.nextui-table-row';

export default TableRow;