import React, { useRef, useImperativeHandle } from 'react';
import { useTableColumnHeader, useTableSelectAllCheckbox } from '@react-aria/table';
import { VisuallyHidden } from '@react-aria/visually-hidden';
import { useFocusRing } from '@react-aria/focus';
import { mergeProps } from '@react-aria/utils';
import Checkbox from '../checkbox';
import { StyledTableHeaderCell } from './table.styles';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const TableSelectAllCheckbox = /*#__PURE__*/React.forwardRef(({
  column,
  state,
  color,
  animated,
  ...props
}, ref) => {
  const tableCellRef = useRef(null);
  useImperativeHandle(ref, () => tableCellRef == null ? void 0 : tableCellRef.current);
  const isSingleSelectionMode = state.selectionManager.selectionMode === 'single';
  const {
    columnHeaderProps
  } = useTableColumnHeader({
    node: column
  }, state, tableCellRef);
  const {
    checkboxProps
  } = useTableSelectAllCheckbox(state);
  const {
    isFocusVisible,
    focusProps
  } = useFocusRing();
  return /*#__PURE__*/_jsx(StyledTableHeaderCell, {
    ref: tableCellRef,
    isFocusVisible: isFocusVisible,
    className: clsx('nextui-table-select-all-checkbox', props.className),
    ...mergeProps(columnHeaderProps, focusProps, props),
    children: isSingleSelectionMode ? /*#__PURE__*/_jsx(VisuallyHidden, {
      children: checkboxProps['aria-label']
    }) : /*#__PURE__*/_jsx(Checkbox, { ...checkboxProps,
      color: color,
      disableAnimation: !animated,
      css: {
        display: 'inherit',
        $$checkboxBorderColor: '$colors$accents3'
      }
    })
  });
});
TableSelectAllCheckbox.displayName = 'NextUI.TableSelectAllCheckbox';

TableSelectAllCheckbox.toString = () => '.nextui-table-select-all-checkbox';

export default TableSelectAllCheckbox;