import React, { useImperativeHandle, useRef } from 'react';
import { useTable } from '@react-aria/table';
import { useTableState } from '@react-stately/table';
import { Spacer } from '../index';
import TableRowGroup from './table-row-group';
import TableColumnHeader from './table-column-header';
import TableHeaderRow from './table-header-row';
import TableSelectAllCheckbox from './table-select-all-checkbox';
import TablePagination from './table-pagination';
import TableFooter from './table-footer';
import TableBody from './table-body';
import { pickSingleChild } from '../utils/collections';
import { StyledTable, StyledTableContainer } from './table.styles';
import TableContext from './table-context';
import { excludedTableProps } from '../utils/prop-types';
import { isInfinityScroll, hasPaginationChild } from './utils';
import withDefaults from '../utils/with-defaults';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const defaultProps = {
  animated: true,
  hideLoading: false,
  selectionMode: 'none',
  selectionBehavior: 'toggle'
};
const Table = /*#__PURE__*/React.forwardRef((tableProps, ref) => {
  const {
    selectionMode,
    selectionBehavior,
    hideLoading,
    children,
    shadow,
    color,
    animated,
    borderWeight,
    bordered,
    containerCss,
    ...props
  } = tableProps;
  const [withoutPaginationChildren, paginationChildren] = pickSingleChild(children, TablePagination);
  const {
    hasPagination,
    rowsPerPage
  } = hasPaginationChild(children, TablePagination);
  const state = useTableState({ ...tableProps,
    children: withoutPaginationChildren,
    showSelectionCheckboxes: tableProps.showSelectionCheckboxes !== undefined ? tableProps.showSelectionCheckboxes : selectionMode === 'multiple' && selectionBehavior !== 'replace'
  }); // clean table props

  Object.keys(props).forEach(propNameKey => {
    if (excludedTableProps.indexOf(propNameKey) > -1) {
      // @ts-ignored
      delete props[propNameKey];
    }
  });
  const tableRef = useRef(null);
  useImperativeHandle(ref, () => tableRef == null ? void 0 : tableRef.current);
  const {
    collection
  } = state;
  const {
    gridProps
  } = useTable(tableProps, state, tableRef);
  const initialValues = React.useMemo(() => {
    return {
      collection,
      color,
      animated,
      rowsPerPage
    };
  }, [collection, animated, color, rowsPerPage]);
  return /*#__PURE__*/_jsx(TableContext.Provider, {
    defaultValues: initialValues,
    children: /*#__PURE__*/_jsx(StyledTableContainer, {
      shadow: shadow,
      borderWeight: borderWeight,
      bordered: bordered,
      className: "nextui-table-container",
      css: { ...containerCss
      },
      children: /*#__PURE__*/_jsxs(StyledTable, {
        ref: tableRef,
        color: color,
        shadow: shadow,
        animated: animated,
        hoverable: selectionMode !== 'none' || props.hoverable,
        isMultiple: selectionMode === 'multiple',
        hasPagination: hasPagination,
        className: clsx('nextui-table', props.className),
        ...gridProps,
        ...props,
        children: [/*#__PURE__*/_jsxs(TableRowGroup, {
          as: "thead",
          isFixed: isInfinityScroll(collection),
          children: [collection.headerRows.map(headerRow => /*#__PURE__*/_jsx(TableHeaderRow, {
            item: headerRow,
            state: state,
            children: [...headerRow.childNodes].map(column => {
              var _column$props;

              return column != null && (_column$props = column.props) != null && _column$props.isSelectionCell ? /*#__PURE__*/_jsx(TableSelectAllCheckbox, {
                column: column,
                state: state,
                color: color,
                animated: animated
              }, column == null ? void 0 : column.key) : /*#__PURE__*/_jsx(TableColumnHeader, {
                column: column,
                state: state,
                animated: animated
              }, column == null ? void 0 : column.key);
            })
          }, headerRow == null ? void 0 : headerRow.key)), !props.sticked && /*#__PURE__*/_jsx(Spacer, {
            as: "tr",
            className: "nextui-table-hidden-row",
            y: 0.4
          })]
        }), /*#__PURE__*/_jsx(TableBody, {
          state: state,
          color: color,
          collection: collection,
          animated: animated,
          hasPagination: hasPagination,
          hideLoading: hideLoading
        }), hasPagination && /*#__PURE__*/_jsxs(TableFooter, {
          children: [/*#__PURE__*/_jsx(Spacer, {
            as: "tr",
            className: "nextui-table-hidden-row",
            y: 0.6
          }), /*#__PURE__*/_jsx("tr", {
            role: "row",
            children: /*#__PURE__*/_jsx("th", {
              tabIndex: -1,
              role: "columnheader",
              colSpan: collection.columnCount,
              children: paginationChildren
            })
          })]
        })]
      })
    })
  });
});
Table.displayName = 'NextUI.Table';

Table.toString = () => '.nextui-table';

export default withDefaults(Table, defaultProps);