import React, { useMemo } from 'react';
import withDefaults from '../utils/with-defaults';
import { isNormalColor } from '../utils/color';
import { useDOMRef } from '../utils/dom';
import { __DEV__ } from '../utils/assertion';
import { StyledText } from './text.styles';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  color: 'default'
};
export const TextChild = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    children,
    tag,
    color: userColor,
    transform,
    margin: marginProp,
    size,
    css,
    ...otherProps
  } = props;
  const domRef = useDOMRef(ref);
  const color = useMemo(() => {
    if (isNormalColor(userColor)) {
      switch (userColor) {
        case 'default':
          return '$text';

        default:
          return `$${userColor}`;
      }
    }

    return userColor;
  }, [userColor]);
  const fontSize = useMemo(() => {
    if (!size) return 'inherit';
    if (typeof size === 'number') return `${size}px`;
    return size;
  }, [size]);
  const margin = useMemo(() => {
    if (!marginProp) return 'inherit';
    if (typeof marginProp === 'number') return `${size}px`;
    return marginProp;
  }, [marginProp]);
  return /*#__PURE__*/_jsx(StyledText, {
    ref: domRef,
    as: tag,
    css: {
      color,
      fontSize: size ? fontSize : '',
      margin,
      tt: transform,
      ...css
    },
    ...otherProps,
    children: children
  });
});

if (__DEV__) {
  TextChild.displayName = 'NextUI.TextChild';
}

TextChild.toString = () => '.nextui-text-child';

const MemoTextChild = /*#__PURE__*/React.memo(TextChild);
export default withDefaults(MemoTextChild, defaultProps);