import React, { useState, useMemo, useEffect } from 'react';
import { SSRProvider } from '@react-aria/ssr';
import { OverlayProvider } from '@react-aria/overlays';
import CssBaseline from '../css-baseline';
import ThemeContext, { defaultContext } from './theme-context';
import withDefaults from '../utils/with-defaults';
import deepMerge from '../utils/deep-merge';
import { copyObject } from '../utils/object';
import { changeTheme, getThemeName, getDocumentCSSTokens, getDocumentTheme } from './utils';
import useSSR from '../use-ssr';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const defaultProps = {
  disableBaseline: false
};

const ThemeProvider = ({
  theme: userTheme,
  disableBaseline,
  children
}) => {
  const {
    isBrowser
  } = useSSR();
  const [currentTheme, setCurrentTheme] = useState(defaultContext.type);

  const changeCurrentTheme = type => {
    setCurrentTheme(ct => ct !== type ? type : ct);
  };

  const changeTypeBaseEl = el => {
    const themeValue = getDocumentTheme(el);
    themeValue && changeCurrentTheme(themeValue);
  };

  const providerValue = useMemo(() => {
    const themeTokens = isBrowser ? getDocumentCSSTokens() : {};
    const theme = deepMerge(copyObject(defaultContext.theme), themeTokens);
    const themeName = getThemeName(currentTheme);
    return {
      theme,
      type: themeName,
      isDark: themeName === 'dark'
    };
  }, [currentTheme, isBrowser]);
  useEffect(() => {
    var _document, _document4, _document5;

    // initial set
    changeTypeBaseEl((_document = document) == null ? void 0 : _document.documentElement);
    const observer = new MutationObserver(mutation => {
      var _mutation$;

      if (mutation && mutation.length > 0 && ((_mutation$ = mutation[0]) == null ? void 0 : _mutation$.target.nodeName) === 'BODY') {
        var _document2, _document2$body, _document2$body$datas;

        const documentTheme = (_document2 = document) == null ? void 0 : (_document2$body = _document2.body) == null ? void 0 : (_document2$body$datas = _document2$body.dataset) == null ? void 0 : _document2$body$datas.theme;
        documentTheme && changeCurrentTheme(documentTheme);
      } else {
        var _document3;

        changeTypeBaseEl((_document3 = document) == null ? void 0 : _document3.documentElement);
      }
    });
    observer.observe((_document4 = document) == null ? void 0 : _document4.documentElement, {
      attributes: true,
      attributeFilter: ['data-theme', 'style']
    });
    observer.observe((_document5 = document) == null ? void 0 : _document5.body, {
      attributes: true,
      attributeFilter: ['data-theme', 'style']
    });
    return () => observer.disconnect();
  }, []);
  useEffect(() => {
    if (!isBrowser || !userTheme) {
      return;
    }

    if (userTheme != null && userTheme.className) {
      changeTheme(userTheme.className);
      changeCurrentTheme(getThemeName(userTheme.className));
    }
  }, [isBrowser, userTheme]);
  return /*#__PURE__*/_jsx(SSRProvider, {
    children: /*#__PURE__*/_jsx(OverlayProvider, {
      children: /*#__PURE__*/_jsxs(ThemeContext.Provider, {
        value: providerValue,
        children: [!disableBaseline && /*#__PURE__*/_jsx(CssBaseline, {}), children]
      })
    })
  });
};

export default withDefaults(ThemeProvider, defaultProps);