import React, { useEffect, useMemo, useRef, useState } from 'react';
import { createPortal } from 'react-dom';
import usePortal from '../use-portal';
import useResize from '../use-resize';
import CSSTransition from '../utils/css-transition';
import useClickAnyWhere from '../use-click-anywhere';
import { getRect, getPlacement, defaultTooltipPlacement, getIconPlacement } from './placement';
import clsx from '../utils/clsx';
import { StyledTooltipContent, StyledTooltip, StyledTooltipArrow } from './tooltip.styles';
import withDefaults from '../utils/with-defaults';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const defaultProps = {
  placement: 'top',
  offset: 12,
  className: ''
};
const preClass = 'nextui-tooltip';

const TooltipContent = ({
  children,
  parent,
  visible,
  offset,
  placement,
  rounded,
  animated,
  className,
  hideArrow,
  css,
  ...props
}) => {
  const el = usePortal('tooltip');
  const selfRef = useRef(null);
  const [rect, setRect] = useState(defaultTooltipPlacement);
  if (!parent) return null;

  const updateRect = () => {
    const pos = getPlacement(placement, getRect(parent), offset);
    setRect(pos);
  };

  const {
    transform,
    top,
    left,
    right,
    bottom
  } = useMemo(() => getIconPlacement(placement, 5), [placement]);
  useResize(updateRect);
  useClickAnyWhere(() => updateRect());
  useEffect(() => {
    updateRect();
  }, [visible]);

  const preventHandler = event => {
    event.stopPropagation();
    event.nativeEvent.stopImmediatePropagation();
  };

  const getState = useMemo(() => {
    return visible ? 'open' : 'closed';
  }, [visible]);
  if (!el) return null;
  return /*#__PURE__*/createPortal( /*#__PURE__*/_jsx(CSSTransition, {
    name: `${preClass}-wrapper`,
    visible: visible,
    enterTime: 20,
    leaveTime: 20,
    children: /*#__PURE__*/_jsx(StyledTooltipContent, {
      className: clsx(`${preClass}-content`, `${preClass}--${getState}`, className),
      "data-state": getState,
      ref: selfRef,
      onClick: preventHandler,
      animated: animated,
      css: {
        left: rect.left,
        top: `calc(${rect.top} + 6px)`,
        transform: rect.transform,
        [`&.${preClass}-wrapper-enter-active`]: {
          opacity: 1,
          top: rect.top
        },
        ...css
      },
      ...props,
      children: /*#__PURE__*/_jsxs(StyledTooltip, {
        role: "tooltip",
        "data-state": getState,
        hideArrow: hideArrow,
        className: clsx(preClass, {
          [`${preClass}--with-arrow`]: !hideArrow
        }),
        children: [/*#__PURE__*/_jsx(StyledTooltipArrow, {
          className: `${preClass}-arrow`,
          css: {
            left,
            top,
            right,
            bottom,
            transform
          }
        }), children]
      })
    })
  }), el);
};

TooltipContent.toString = () => '.nextui-tooltip-content';

export default withDefaults(TooltipContent, defaultProps);