import React from 'react';
import { Avatar } from '../index';
import { useDOMRef } from '../utils/dom';
import { __DEV__ } from '../utils/assertion';
import { StyledUser, StyledUserInfo, StyledUserName, StyledUserDesc } from './user.styles';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const defaultProps = {
  size: 'lg',
  squared: false,
  bordered: false
};
const preClass = 'nextui-user';
export const User = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    src,
    text,
    name,
    children,
    altText,
    color,
    squared,
    bordered,
    size,
    description,
    ...otherProps
  } = props;
  const domRef = useDOMRef(ref);
  return /*#__PURE__*/_jsxs(StyledUser, {
    ref: domRef,
    ...otherProps,
    children: [/*#__PURE__*/_jsx(Avatar, {
      className: `${preClass}-avatar`,
      src: src,
      color: color,
      squared: squared,
      zoomed: props.zoomed,
      pointer: props.pointer,
      bordered: bordered,
      text: text,
      size: size,
      alt: altText
    }), /*#__PURE__*/_jsxs(StyledUserInfo, {
      className: `${preClass}-info`,
      children: [/*#__PURE__*/_jsx(StyledUserName, {
        className: `${preClass}-name`,
        children: name
      }), /*#__PURE__*/_jsx(StyledUserDesc, {
        className: `${preClass}-desc`,
        children: description || children
      })]
    })]
  });
});

if (__DEV__) {
  User.displayName = 'NextUI.User';
}

User.toString = () => '.nextui-user';

export default User;