import React, { useEffect, useState } from 'react';
import withDefaults from './with-defaults';
import clsx from './clsx';
const defaultProps = {
  visible: false,
  enterTime: 60,
  leaveTime: 60,
  clearTime: 60,
  className: '',
  name: 'transition'
};

const CSSTransition = ({
  children,
  childrenRef,
  className,
  visible,
  enterTime,
  leaveTime,
  clearTime,
  name,
  onExited,
  onEntered,
  ...props
}) => {
  const [classes, setClasses] = useState('');
  const [renderable, setRenderable] = useState(visible);
  useEffect(() => {
    const statusClassName = visible ? 'enter' : 'leave';
    const time = visible ? enterTime : leaveTime;

    if (visible && !renderable) {
      setRenderable(true);
    }

    setClasses(`${name}-${statusClassName}`); // set class to active

    const timer = setTimeout(() => {
      setClasses(`${name}-${statusClassName} ${name}-${statusClassName}-active`);

      if (statusClassName === 'leave') {
        onExited == null ? void 0 : onExited();
      } else {
        onEntered == null ? void 0 : onEntered();
      }

      clearTimeout(timer);
    }, time); // remove classess when animation over

    const clearClassesTimer = setTimeout(() => {
      if (!visible) {
        setClasses('');
        setRenderable(false);
      }

      clearTimeout(clearClassesTimer);
    }, time + clearTime);
    return () => {
      clearTimeout(timer);
      clearTimeout(clearClassesTimer);
    };
  }, [visible, renderable]); // update children ref classes

  useEffect(() => {
    if (!(childrenRef != null && childrenRef.current)) {
      return;
    }

    const classesArr = classes.split(' ');
    const refClassesArr = childrenRef.current.className.split(' ');
    const newRefClassesArr = refClassesArr.filter(item => !item.includes(name));
    childrenRef.current.className = clsx(newRefClassesArr, classesArr);
  }, [childrenRef, classes]);
  if (! /*#__PURE__*/React.isValidElement(children) || !renderable) return null;
  return /*#__PURE__*/React.cloneElement(children, { ...props,
    className: clsx(children.props.className, className, !(childrenRef != null && childrenRef.current) ? classes : '')
  });
};

export default withDefaults(CSSTransition, defaultProps);