import React, { useEffect, useRef } from 'react';
import { styled, keyframes } from '../theme/stitches.config';
import withDefaults from '../utils/with-defaults';
import clsx from '../utils/clsx';
import { jsx as _jsx } from "react/jsx-runtime";
const defaultProps = {
  visible: false,
  x: 0,
  y: 0,
  className: ''
};
const expand = keyframes({
  '0%': {
    opacity: 0,
    transform: 'scale(0.25)'
  },
  '30%': {
    opacity: 1
  },
  '80%': {
    opacity: 0.5
  },
  '100%': {
    transform: 'scale(28)',
    opacity: 0
  }
});
export const StyledDrip = styled('div', {
  position: 'absolute',
  left: 0,
  right: 0,
  top: 0,
  bottom: 0,
  '& svg': {
    position: 'absolute',
    animation: `350ms linear ${expand}`,
    animationFillMode: 'forwards',
    width: '$md',
    height: '$md'
  }
});

const Drip = ({
  visible,
  x,
  y,
  color,
  onCompleted,
  className,
  ...props
}) => {
  const dripRef = useRef(null);
  const top = Number.isNaN(+y) ? 0 : y - 10;
  const left = Number.isNaN(+x) ? 0 : x - 10;
  useEffect(() => {
    if (!dripRef.current) return;
    dripRef.current.addEventListener('animationend', onCompleted);
    return () => {
      if (!dripRef.current) return;
      dripRef.current.removeEventListener('animationend', onCompleted);
    };
  });
  if (!visible) return null;
  return /*#__PURE__*/_jsx(StyledDrip, {
    ref: dripRef,
    className: clsx('nextui-drip', className),
    ...props,
    children: /*#__PURE__*/_jsx("svg", {
      width: "20",
      height: "20",
      viewBox: "0 0 20 20",
      style: {
        top,
        left
      },
      children: /*#__PURE__*/_jsx("g", {
        stroke: "none",
        strokeWidth: "1",
        fill: "none",
        fillRule: "evenodd",
        children: /*#__PURE__*/_jsx("g", {
          className: "nextui-drip-filler",
          fill: color,
          children: /*#__PURE__*/_jsx("rect", {
            width: "100%",
            height: "100%",
            rx: "10"
          })
        })
      })
    })
  });
};

const MemoDrip = /*#__PURE__*/React.memo(Drip);
export default withDefaults(MemoDrip, defaultProps);