export const isObject = target => target && typeof target === 'object';
export const renameProp = (oldProp, newProp, {
  [oldProp]: old,
  ...others
}) => ({
  [newProp]: old,
  ...others
}); // copy an object without reference

export const copyObject = obj => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  return { ...obj
  };
}; // copy an object omit some keys

export const omitObject = (obj, omitKeys) => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  const newObj = { ...obj
  };
  omitKeys.forEach(key => newObj[key] && delete newObj[key]);
  return newObj;
}; // clean undefined and null values

export const cleanObject = obj => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  const newObj = { ...obj
  };
  Object.keys(newObj).forEach(key => {
    if (newObj[key] === undefined || newObj[key] === null) {
      delete newObj[key];
    }
  });
  return newObj;
};
export const cleanObjectKeys = (obj, keys = []) => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  const newObj = { ...obj
  };
  keys.forEach(key => {
    if (newObj[key]) {
      delete newObj[key];
    }
  });
  return newObj;
};
export const getKeyValue = (obj, key) => {
  if (!isObject(obj)) return obj;
  if (obj instanceof Array) return [...obj];
  return obj[key];
};