import React, { ReactNode } from 'react';
import RadioGroup from './radio-group';
import { SimpleColors, NormalSizes } from '../utils/prop-types';
import { CSS } from '../theme/stitches.config';
import { StyledRadioDescription, RadioVariantsProps } from './radio.styles';
interface RadioEventTarget {
    checked: boolean;
}
export interface RadioEvent {
    target: RadioEventTarget;
    stopPropagation: () => void;
    preventDefault: () => void;
    nativeEvent: React.ChangeEvent;
}
interface Props {
    children?: ReactNode;
    checked?: boolean;
    value?: string | number;
    size?: NormalSizes;
    color?: SimpleColors;
    textColor?: SimpleColors;
    disabled?: boolean;
    preventDefault?: boolean;
    onChange?: (e: RadioEvent) => void;
}
declare const defaultProps: {
    size: "xs" | "sm" | "md" | "lg" | "xl";
    color: "default" | "primary" | "secondary" | "success" | "warning" | "error";
    textColor: "default" | "primary" | "secondary" | "success" | "warning" | "error";
    disabled: boolean;
    preventDefault: boolean;
};
declare type NativeAttrs = Omit<React.InputHTMLAttributes<unknown>, keyof Props>;
export declare type RadioProps = Props & typeof defaultProps & NativeAttrs & RadioVariantsProps & {
    css?: CSS;
};
export declare const Radio: React.ForwardRefExoticComponent<Props & {
    size: "xs" | "sm" | "md" | "lg" | "xl";
    color: "default" | "primary" | "secondary" | "success" | "warning" | "error";
    textColor: "default" | "primary" | "secondary" | "success" | "warning" | "error";
    disabled: boolean;
    preventDefault: boolean;
} & NativeAttrs & import("@stitches/react/types/styled-component").TransformProps<{
    color?: "default" | "primary" | "secondary" | "success" | "warning" | "error" | undefined;
    size?: "xs" | "sm" | "md" | "lg" | "xl" | undefined;
    disabled?: boolean | "true" | undefined;
    squared?: boolean | "true" | "false" | undefined;
    active?: boolean | "true" | undefined;
    animated?: boolean | "true" | "false" | undefined;
}, {
    xs: string;
    sm: string;
    md: string;
    lg: string;
    xl: string;
    xsMax: string;
    smMax: string;
    mdMax: string;
    lgMax: string;
    xlMax: string;
    motion: string;
    safari: string;
    hover: string;
    dark: string;
    light: string;
}> & {
    css?: CSS | undefined;
} & React.RefAttributes<HTMLInputElement>>;
declare type RadioComponent<P = {}> = React.FC<P> & {
    Group: typeof RadioGroup;
    Desc: typeof StyledRadioDescription;
    Description: typeof StyledRadioDescription;
};
declare type ComponentProps = Partial<typeof defaultProps> & Omit<Props, keyof typeof defaultProps> & NativeAttrs & RadioVariantsProps & {
    css?: CSS;
};
declare const _default: RadioComponent<ComponentProps>;
export default _default;
